@@ -3,7 +3,7 @@
      engine.c: Satellite tracking routines stolen from Predict           
                http://www.qsl.net/kd2bd/predict.html                     
 
-  Copyright (C)  2001-2003  Alexandru Csete & John A. Magliacane.
+  Copyright (C)  2001-2005  Alexandru Csete & John A. Magliacane.
 
   Authors:  Alexandru Csete <csete@users.sourceforge.net>,
             John A. Magliacane
@@ -638,14 +638,14 @@ Calc (guint i , gdouble dnum)
 		/* Update status */
 		switch (sat_table[i]->status) {
 		case SAT_STATUS_NONE:
-			if ( sat_table[i]->el>0 ) {
+			if (sat_table[i]->el > 0.0) {
 				sat_table[i]->status = SAT_STATUS_CAMEUP;
 				sat_table[i]->los = aos_find_los( *sat_table[i],
 								  CurrentDaynum()+0.005 );
 				sat_table[i]->aos = aos_find_aos( *sat_table[i],
 								  sat_table[i]->los+0.015 );
 			}
-			if ( sat_table[i]->el<0) {
+			if (sat_table[i]->el < 0.0) {
 				sat_table[i]->status = SAT_STATUS_WENTDOWN;
 				sat_table[i]->aos = aos_find_aos( *sat_table[i],
 								  CurrentDaynum()+0.005 );
@@ -654,16 +654,16 @@ Calc (guint i , gdouble dnum)
 			}
 			break;
 		case SAT_STATUS_BHOR:
-			if (sat_table[i]->el>0) {
+			if (sat_table[i]->el > 0.0) {
 				sat_table[i]->los = aos_find_los( *sat_table[i],
-								  CurrentDaynum()+0.005 );
+								  CurrentDaynum()+0.005);
 				sat_table[i]->aos = aos_find_aos( *sat_table[i],
-								  sat_table[i]->los+0.005 );
+								  sat_table[i]->los+0.015);
 				sat_table[i]->status = SAT_STATUS_CAMEUP;
 			}
 			break;
 		case SAT_STATUS_AHOR:
-			if (sat_table[i]->el<0) {
+			if (sat_table[i]->el < 0.0) {
 				sat_table[i]->aos = aos_find_aos( *sat_table[i],
 								  CurrentDaynum()+0.005 );
 				sat_table[i]->los = aos_find_los( *sat_table[i],
