@@ -2,7 +2,7 @@
 /*
   main.c: ....
 
-  Copyright (C)  2001-2003  Alexandru Csete.
+  Copyright (C)  2001-2005  Alexandru Csete.
 
   Authors: Alexandru Csete <csete@users.sourceforge.net>
 
@@ -55,6 +55,7 @@
 #include "newuser.h"
 #include "iconbar.h"
 #include "satmodules.h"
+#include "sattarget.h"
 #include "sattree.h"
 #include "satloc-tree.h"
 
@@ -82,7 +83,12 @@ sat_t *sat;
 static void reopen_modules (void);
 static void do_tree_hack (void);
 
-#define CONFIGVERSION 0.4
+/* CONFIGVERSION:
+     CFGVER 0.4 is used for SW version 0.4.0
+                                       0.4.99.1;0.4.99.2;0.4.99.3;0.4.99.4;0.4.99.5;0.4.99.6;0.4.99.7
+     CFGVER 0.5 is used for SW version 0.4.99.8
+*/
+#define CONFIGVERSION 0.5
 
 
 int main(int argc, char *argv[])
@@ -99,10 +105,17 @@ int main(int argc, char *argv[])
 	gnome_init (PACKAGE, VERSION, argc, argv);
 	gnome_vfs_init ();
 
+	/* window icon - must be called BEFORE gnome_app_new ??? */
+	path = g_strconcat (PACKAGE_PIXMAPS_DIR, G_DIR_SEPARATOR_S, "icons",
+			    G_DIR_SEPARATOR_S, "gpredict-icon.png", NULL);
+	gnome_window_icon_set_default_from_file (path);
+	g_free (path);
+
 	/* create application */
 	title = g_strconcat ("Gnome Predict ", VERSION, NULL);
 	app = gnome_app_new (PACKAGE, title);
 	g_free (title);
+	gnome_window_icon_set_from_default (GTK_WINDOW (app));
 
 	/* init GConf */
 	if (!gconf_is_initialized ())
@@ -121,8 +134,6 @@ int main(int argc, char *argv[])
 	   any existing pre-1.0 configuration files to the proper GConf
 	   configuration.
 	*/
-
-/* 	if (!gconf_client_dir_exists (client, QTH_ROOT_PATH, NULL)) {  THIS DIDN'T WORK FOR SOME REASON */
 	if (gconf_client_get_float (client, "/apps/gpredict/version", NULL) < CONFIGVERSION) {
 		g_print ("CONFIG NOT OK!\n");
 		satlog_log (SAT_LOG_INFO, _("Configuration is not up to date!"));
@@ -153,34 +164,12 @@ int main(int argc, char *argv[])
 		satlog_log (SAT_LOG_INFO, _("Configuration OK."));
 	}
 
-
-	/* Check for the existence of some config files. Also, if the user has
-	   a proper version 0.2 configuration, use that.
-	*/
-/* 	path = g_strconcat (g_get_home_dir (), G_DIR_SEPARATOR_S, ".gpredict", */
-/* 			    G_DIR_SEPARATOR_S, "default.qth", NULL); */
-/* 	if (!g_file_test (path, G_FILE_TEST_ISFILE)) { */
-		/* QTH file is missing - Run new user druid */
-/* 		newuser_init (); */
-/* 		gtk_main (); */
-/* 		if (!USEROK) */
-/* 			return 1; */
-/* 	} */
-/* 	g_free (path); */
-
+	/* initialize engine */
 	i = engine_init ();
 
 	/* initialize log */
 	if (gconf_client_get_bool (client, SATLOG_VISIBLE_PATH, NULL))
 		satlog_show ();
-//		satlog_init ();
-
-
-	/* window icon */
-	path = g_strconcat (PACKAGE_PIXMAPS_DIR,"/icons/gpredict-icon.png",NULL);
-	gnome_window_icon_set_from_file (GTK_WINDOW (app), path);
-//	gnome_window_icon_set_default_from_file (path);
-	g_free (path);
 
 	gtk_window_set_default_size (GTK_WINDOW (app), 800, 550 );
 	gtk_signal_connect (GTK_OBJECT (app), "delete_event",
@@ -201,13 +190,16 @@ int main(int argc, char *argv[])
 
 	gtk_box_pack_start (GTK_BOX (vbox), gtk_hseparator_new (), FALSE, FALSE, 0);
 
-	/* Sun and moon */
+	/* Bottom infobox of the main window */
 	toolhbox = gtk_hbox_new (FALSE, 1);
 	gtk_box_pack_start (GTK_BOX (toolhbox), sun_create (),
 			    FALSE, FALSE, 2);
 	gtk_box_pack_start (GTK_BOX (toolhbox), moon_create (),
-			    FALSE, FALSE, 2 );
-	
+			    FALSE, FALSE, 2);
+/* #if defined (HAVE_HAMLIB) */
+/* 	gtk_box_pack_start (GTK_BOX (toolhbox), sattarget_create (), */
+/* 			    FALSE, FALSE, 2); */
+/* #endif */
 	gtk_box_pack_end (GTK_BOX (vbox), toolhbox, FALSE, FALSE, 0);
 
 	gnome_app_set_contents (GNOME_APP (app), GTK_WIDGET (vbox));
@@ -284,8 +276,6 @@ do_tree_hack ()
 
 
 	tree = sattree_load_uris_recursive (loc, web, filter, SATTREE_MODE_FILE);
-//	tree = satloc_tree_create ();
-
 
 	g_strfreev (loc);
 	g_strfreev (web);
