@@ -6,7 +6,7 @@
 			 callbacks related to ground station locations.
 
 
-  Copyright (C)  2002-2003  Alexandru Csete.
+  Copyright (C)  2002-2005  Alexandru Csete.
 
   Authors: Alexandru Csete <csete@users.sourceforge.net>
 
@@ -45,7 +45,8 @@
 #  include "../config.h"
 #endif
 
-#if defined (HAVE_LIBHAMLIB) && defined (HAVE_HAMLIB_ROTATOR_H)
+
+#if defined (HAVE_HAMLIB)
 #  include <hamlib/rotator.h>
 
 
@@ -70,6 +71,7 @@ static GtkWidget *wxsta;                               /* nearest weather statio
 static GtkWidget *qra_loc;                             /* QRA locator */
 
 GtkWidget *radio1,*radio2;
+extern GtkWidget *druid;    /* in satconfig.c */
 
 /* This structure is used as buffer when the user
    selects a row in the locations tree.
@@ -82,25 +84,41 @@ static struct {
 	gchar *wx;
 } selection;
 
+
+/* default QTH, if already configured */
+static gint defqth = -1;
+
+
 /* private function prototypes */
-static void     satconfig_locations_locbut_cb              (GtkWidget *button,
-							    gpointer data);
-static void     satconfig_locations_loctree_select_cb      (GtkCTree *ctree,
-							    GList *node,
-							    gint column,
-							    gpointer dialog);
-static void     satconfig_locations_loctree_unselect_cb    (GtkCTree *ctree,
-							    GList *node,
-							    gint column,
-							    gpointer dialog);
-static void     satconfig_locations_wxbut_cb               (GtkWidget *button, 
-							    gpointer data);
-static gboolean satconfig_locations_read_predict_qth       (void);
-static gboolean satconfig_locations_read_gnome_predict_qth (void);
+static void     satconfig_locations_locbut_cb                   (GtkWidget *button,
+								 gpointer data);
+
+static void     satconfig_locations_loctree_select_cb           (GtkCTree *ctree,
+								 GList    *node,
+								 gint      column,
+								 gpointer  dialog);
+
+static void     satconfig_locations_loctree_unselect_cb         (GtkCTree *ctree,
+								 GList    *node,
+								 gint     column,
+								 gpointer   dialog);
+
+static void     satconfig_locations_wxbut_cb                    (GtkWidget *button, 
+								 gpointer   data);
+
+static gboolean satconfig_locations_read_predict_qth            (void);
+static gboolean satconfig_locations_read_gnome_predict_qth      (void);
+static gboolean satconfig_locations_read_gnome_predict_0_4_qth  (void);
+
+static void     satconfig_locations_prepare_cb                  (GnomeDruidPage *druidpage,
+								 GtkWidget      *druid,
+								 gpointer        data);
+
+static void     satconfig_locations_name_cb                     (GtkEntry *entry, gpointer data);
 
 
-GtkWidget
-*satconfig_locations_open (void)
+GtkWidget *
+satconfig_locations_open (void)
 {
 	/* This function creates and returns the QTH config
 	   page. It also checks, whether the user already has
@@ -128,9 +146,13 @@ GtkWidget
 	tips = gtk_tooltips_new ();
 	gtk_tooltips_set_tip (tips, qth_name,
 			      _("Enter the name of your ground station or your callsign, "\
-				"if you happen to be a radio amateur. This field is optional."),
+				"if you happen to be a radio amateur. This field is mandatory."),
 			      _("This name will be used on various occasions like prints or saved images."));
 	gtk_table_attach_defaults (GTK_TABLE (table), qth_name, 2, 4, 0, 1);
+
+	/* connect the changed signal */
+	gtk_signal_connect (GTK_OBJECT (qth_name), "changed",
+			    GTK_SIGNAL_FUNC (satconfig_locations_name_cb), NULL);
 	
 	/* Description */
 	label = gtk_label_new (_("Description:"));
@@ -247,11 +269,12 @@ GtkWidget
 				"near your location."));
 	gtk_table_attach_defaults (GTK_TABLE (table), wxbut, 3, 4, 9, 10);
 
-#if defined (HAVE_LIBHAMLIB) && defined (HAVE_HAMLIB_ROTATOR_H)
+#if defined (HAVE_HAMLIB)
 	/* QRA locator */
 	label = gtk_label_new (_("Locator:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
 	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 5, 6);
+//	gtk_table_attach (GTK_TABLE (table), label, 1, 2, 5, 6, GTK_SHRINK, GTK_SHRINK, 0, 0);
 	qra_loc = gtk_entry_new ();
 	gtk_signal_connect (GTK_OBJECT (qra_loc), "changed",
 			    GTK_SIGNAL_FUNC (satconfig_locations_qra_changed_cb),
@@ -295,11 +318,12 @@ GtkWidget
 #endif
 
 	/* Check for existing configuration */
-	if (!satconfig_locations_read_gnome_predict_qth ()) {
-		satconfig_locations_read_predict_qth ();
+	if (!satconfig_locations_read_gnome_predict_0_4_qth ()) {
+		if (!satconfig_locations_read_gnome_predict_qth ()) {
+			satconfig_locations_read_predict_qth ();
+		}
 	}
 
-
 	/* create the page */
 	qthpage = gnome_druid_page_standard_new ();
 	gnome_druid_page_standard_set_title (GNOME_DRUID_PAGE_STANDARD (qthpage),
@@ -308,6 +332,12 @@ GtkWidget
 	gnome_druid_page_standard_set_title_color (GNOME_DRUID_PAGE_STANDARD (qthpage), &mainbg);
 	gnome_druid_page_standard_set_logo_bg_color (GNOME_DRUID_PAGE_STANDARD (qthpage), &logobg);
 
+	/* Connect the "prepare" signal so that we can disable the next button. It will be enabled
+	   if we have a reasonable value in the QTH name field.
+	*/
+	gtk_signal_connect (GTK_OBJECT (qthpage), "prepare",
+			    GTK_SIGNAL_FUNC (satconfig_locations_prepare_cb), NULL);
+
 	/* add logo */
 	fname = g_strconcat (PACKAGE_PIXMAPS_DIR, G_DIR_SEPARATOR_S,
 			     "icons", G_DIR_SEPARATOR_S, "gpredict-home.png",
@@ -337,12 +367,22 @@ satconfig_locations_finish (void)
 	gchar *key;
 	gboolean ok = TRUE;
 
+	/* Check whether we have a default QTH, otherwise make default 0.
+	   One may argue, that if we already did have a QTH configuration,
+	   we should not rewrite it. Then again, the user might have made some
+	   modifications.
+	*/
+	if (defqth == -1) {
+		defqth = 0;
+	}
+
 	/* QTH Name */
-	key = g_strconcat (QTH_ROOT_PATH, "/qth0_name", NULL);
+	key = g_strdup_printf ("%s/qth%d_name", QTH_ROOT_PATH, defqth);
 	if (gtk_entry_get_text (GTK_ENTRY (qth_name)) != NULL)
 		ok = ok && gconf_client_set_string (client, key, 
 						    gtk_entry_get_text (GTK_ENTRY (qth_name)),
 						    NULL);
+	/* FIXME: As of 0.4.99.8 this field can't be empty! */
 	else
 		ok = ok && gconf_client_set_string (client, key,
 						    _("Some Station"),
@@ -350,7 +390,7 @@ satconfig_locations_finish (void)
 	g_free (key);
 
 	/* QTH Description */
-	key = g_strconcat (QTH_ROOT_PATH, "/qth0_description", NULL);
+	key = g_strdup_printf ("%s/qth%d_description", QTH_ROOT_PATH, defqth);
 	if (gtk_entry_get_text (GTK_ENTRY (qth_desc)) != NULL)
 		ok = ok && gconf_client_set_string (client, key,
 						    gtk_entry_get_text (GTK_ENTRY (qth_desc)),
@@ -362,7 +402,7 @@ satconfig_locations_finish (void)
 	g_free (key);
 
 	/* QTH Location */
-	key = g_strconcat (QTH_ROOT_PATH, "/qth0_location", NULL);
+	key = g_strdup_printf ("%s/qth%d_location", QTH_ROOT_PATH, defqth);
 	if (gtk_entry_get_text (GTK_ENTRY (qth_loc)) != NULL)
 		ok = ok && gconf_client_set_string (client, key,
 						    gtk_entry_get_text (GTK_ENTRY (qth_loc)),
@@ -375,7 +415,7 @@ satconfig_locations_finish (void)
 
 	/* Weather Station */
 	if (gtk_entry_get_text (GTK_ENTRY (wxsta)) != NULL) {
-		key = g_strconcat (QTH_ROOT_PATH, "/qth0_wxsta", NULL);
+		key = g_strdup_printf ("%s/qth%d_wxsta", QTH_ROOT_PATH, defqth);
 		ok = ok && gconf_client_set_string (client, key,
 						    gtk_entry_get_text (GTK_ENTRY (wxsta)),
 						    NULL);
@@ -384,7 +424,7 @@ satconfig_locations_finish (void)
 
 	/* QRA Locator */
 	if (gtk_entry_get_text (GTK_ENTRY (qra_loc)) != NULL) {
-		key = g_strconcat (QTH_ROOT_PATH, "/qth0_qra", NULL);
+		key = g_strdup_printf ("%s/qth%d_qra", QTH_ROOT_PATH, defqth);
 		ok = ok && gconf_client_set_string (client, key,
 						    gtk_entry_get_text (GTK_ENTRY (qra_loc)),
 						    NULL);
@@ -392,21 +432,21 @@ satconfig_locations_finish (void)
 	}
 
 	/* QTH latitude */
-	key = g_strconcat (QTH_ROOT_PATH, "/qth0_lat", NULL);
+	key = g_strdup_printf ("%s/qth%d_lat", QTH_ROOT_PATH, defqth);
 	ok = ok && gconf_client_set_float (client, key,
 					   gtk_spin_button_get_value_as_float (GTK_SPIN_BUTTON (latsp)),
 					   NULL);
 	g_free (key);
 
 	/* QTH Longitude */
-	key = g_strconcat (QTH_ROOT_PATH, "/qth0_lon", NULL);
+	key = g_strdup_printf ("%s/qth%d_lon", QTH_ROOT_PATH, defqth);
 	ok = ok && gconf_client_set_float (client, key,
 					   gtk_spin_button_get_value_as_float (GTK_SPIN_BUTTON (lonsp)),
 					   NULL);
 	g_free (key);
 
 	/* QTH Altitude */
-	key = g_strconcat (QTH_ROOT_PATH, "/qth0_alt", NULL);
+	key = g_strdup_printf ("%s/qth%d_alt", QTH_ROOT_PATH, defqth);
 	ok = ok && gconf_client_set_int (client, key,
 					 gtk_spin_button_get_value_as_float (GTK_SPIN_BUTTON (altsp)),
 					 NULL);
@@ -750,12 +790,154 @@ satconfig_locations_read_gnome_predict_qth (void)
 	return FALSE;
 }
 
+static gboolean
+satconfig_locations_read_gnome_predict_0_4_qth (void)
+{
+	/* Check for QTH configuration (post 0.4.0 versions) */
+	gchar *key;
+	gchar *buff;
+
+	if (gconf_client_dir_exists (client, QTH_ROOT_PATH, NULL)) {
+
+		/* get default */
+		key = g_strdup_printf ("%s/default", QTH_ROOT_PATH);
+		defqth = gconf_client_get_int (client, key, NULL);
+		g_free (key);
+
+		/* get name */
+		key = g_strdup_printf ("%s/qth%d_name", QTH_ROOT_PATH, defqth);
+		buff = g_strdup (gconf_client_get_string (client, key, NULL));
+		if (buff) {
+			gtk_entry_set_text (GTK_ENTRY (qth_name), buff);
+		}
+		g_free (buff);
+		g_free (key);
+
+		/* get description */
+		key = g_strdup_printf ("%s/qth%d_description", QTH_ROOT_PATH, defqth);
+		buff = g_strdup (gconf_client_get_string (client, key, NULL));
+		if (buff) {
+			gtk_entry_set_text (GTK_ENTRY (qth_desc), buff);
+		}
+		g_free (buff);
+		g_free (key);
+
+		/* get location */
+		key = g_strdup_printf ("%s/qth%d_location", QTH_ROOT_PATH, defqth);
+		buff = g_strdup (gconf_client_get_string (client, key, NULL));
+		if (buff) {
+			gtk_entry_set_text (GTK_ENTRY (qth_loc), buff);
+		}
+		g_free (buff);
+		g_free (key);
+
+		/* get weather station */
+		key = g_strdup_printf ("%s/qth%d_wxsta", QTH_ROOT_PATH, defqth);
+		buff = g_strdup (gconf_client_get_string (client, key, NULL));
+		if (buff) {
+			gtk_entry_set_text (GTK_ENTRY (wxsta), buff);
+		}
+		g_free (buff);
+		g_free (key);
+
+		/* get latitude */
+		key = g_strdup_printf ("%s/qth%d_lat", QTH_ROOT_PATH, defqth);
+		gtk_spin_button_set_value (GTK_SPIN_BUTTON (latsp), gconf_client_get_float (client, key, NULL));
+		g_free (key);
+
+		/* get longitude */
+		key = g_strdup_printf ("%s/qth%d_lon", QTH_ROOT_PATH, defqth);
+		gtk_spin_button_set_value (GTK_SPIN_BUTTON (lonsp), gconf_client_get_float (client, key, NULL));
+		g_free (key);
+
+		/* get altitude */
+		key = g_strdup_printf ("%s/qth%d_alt", QTH_ROOT_PATH, defqth);
+		gtk_spin_button_set_value (GTK_SPIN_BUTTON (altsp), gconf_client_get_int (client, key, NULL));
+		g_free (key);
+
+#if defined (HAVE_HAMLIB)
+		/* get QRA locator */
+		key = g_strdup_printf ("%s/qth%d_qra", QTH_ROOT_PATH, defqth);
+		buff = g_strdup (gconf_client_get_string (client, key, NULL));
+		if (buff) {
+			gtk_entry_set_text (GTK_ENTRY (qra_loc), buff);
+		}
+		g_free (buff);
+		g_free (key);
+#endif
+
+		return TRUE;
+	}
+
+	return FALSE;
+}
 
 
 
+/**
+ * \brief Handle prepare signals for the QTH config page.
+ * \param druidpage The GnomeDruidPage that received the signal.
+ * \param druid     The GnomeDruid that emitted the signal.
+ * \param data      User data.
+ *
+ * This function is called when the satconfig-locations druid page receives the
+ * prepare signal from the man druid. This means that the druid is abouet to show
+ * this page. The idea with this function is to diable the Next button until a
+ * reasonable value has been entered to the Name/Call field.
+ *
+ * \internal
+ */
+static void
+satconfig_locations_prepare_cb             (GnomeDruidPage *druidpage,
+					    GtkWidget      *druid,
+					    gpointer        data)
+{
+	gchar *text;
 
-/** THe rest is only included if hamlib 1.1.3 or later is used **/
-#if defined (HAVE_LIBHAMLIB) && defined (HAVE_HAMLIB_ROTATOR_H)
+	/* get text from qth_name widget */
+	text = gtk_entry_get_text (GTK_ENTRY (qth_name));
+
+	/* If there is some text, enable all buttons */
+	if ((text != NULL) && g_strcasecmp (text, "")) {
+		gnome_druid_set_buttons_sensitive (GNOME_DRUID (druid), TRUE, TRUE, TRUE);
+	}
+	/* otherwise disable the next button */
+	else {
+		gnome_druid_set_buttons_sensitive (GNOME_DRUID (druid), TRUE, FALSE, TRUE);
+	}
+}
+
+
+
+/**
+ * \brief Handle changed signals for the QTH name entry widget.
+ * \param entry The GtkEntry that received the signal.
+ * \param data  User data.
+ * 
+ * This function is called when the user modifies the text in the QTH name entry. The
+ * purpose with this function is to enable or disable the Next button, depending on whether
+ * the name entry contains some text or not.
+ *
+ * \internal
+ */
+static void
+satconfig_locations_name_cb                (GtkEntry *entry, gpointer data)
+{
+	gchar *text;
+
+	text = gtk_entry_get_text (entry);
+	if ((text != NULL) && g_strcasecmp (text, "")) {
+		gnome_druid_set_buttons_sensitive (GNOME_DRUID (druid), TRUE, TRUE, TRUE);
+	}
+	else {
+		gnome_druid_set_buttons_sensitive (GNOME_DRUID (druid), TRUE, FALSE, TRUE);
+	}
+}
+
+
+
+/* The rest is only included if hamlib 1.2.0 or later is used */
+#if defined (HAVE_HAMLIB)
 
 static void
 satconfig_locations_latlon_cb              (GtkAdjustment *adj, gpointer data)
@@ -763,15 +945,27 @@ satconfig_locations_latlon_cb              (GtkAdjustment *adj, gpointer data)
 	/* This function is called when either the latitude or the longitude spin
 	   button is changed. It updates the locator entry.
 	*/
-	gchar *locator;
+	gchar locator[2*QRA_PAIR_COUNT+1];
 
+	/* Check whether user is typing into lat/lon entries or the change comes from
+	   automatic conversion (this can be checked by reading the status of the
+	   longitude-latitude radio button).
+	*/
 	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (radio1))) {
-		locator = g_malloc (7);
-		longlat2locator (gtk_spin_button_get_value_as_float (GTK_SPIN_BUTTON (lonsp)),
-				 gtk_spin_button_get_value_as_float (GTK_SPIN_BUTTON (latsp)),
-				 locator);
-		gtk_entry_set_text (GTK_ENTRY (qra_loc), locator);
-		g_free (locator);
+		/* Try to convert input */
+		if (longlat2locator (-gtk_spin_button_get_value_as_float (GTK_SPIN_BUTTON (lonsp)),
+				     gtk_spin_button_get_value_as_float (GTK_SPIN_BUTTON (latsp)),
+				     locator, QRA_PAIR_COUNT) == RIG_OK) {
+			
+			/* Conversion is OK, update locator field */
+			gtk_entry_set_text (GTK_ENTRY (qra_loc), g_strdup (locator));
+		}
+		else {
+			/* Clear locator field and disable "Next" button
+			   because user is typing some junk.
+			   This could be avoided by using spinbuttons! */
+			gtk_entry_set_text (GTK_ENTRY (qra_loc), "");
+		}
 	}
 }
 
@@ -813,9 +1007,11 @@ satconfig_locations_qra_changed_cb    (GtkWidget *qra, gpointer data)
 
 		if (!locator2longlat (&lon, &lat, gtk_entry_get_text (GTK_ENTRY (qra)))) {
 			gtk_spin_button_set_value (GTK_SPIN_BUTTON (latsp), lat);
-			gtk_spin_button_set_value (GTK_SPIN_BUTTON (lonsp), lon);
+			gtk_spin_button_set_value (GTK_SPIN_BUTTON (lonsp), -lon);
 		}
 	}
 }
 
 #endif
+
+
