@@ -5,7 +5,7 @@
                          This module is responsible for the widgets and
 			 callbacks related to ground station locations.
 
-  Copyright (C)  2002-2003  Alexandru Csete.
+  Copyright (C)  2002-2005  Alexandru Csete.
 
   Authors: Alexandru Csete <csete@users.sourceforge.net>
 
@@ -34,6 +34,14 @@
 #ifndef SATCONFIG_LOCATIONS_H
 #define SATCONFIG_LOCATIONS_H
 
+/* The pair count (resolution?) when calculationg mainhead locator.
+   I assume, that the returned locator will contain 2 times pair_count
+   characters.
+   This parameter has to be passed to the longlat2locator procedure
+   as of hamlib V1.2
+*/
+#define QRA_PAIR_COUNT 3
+
 GtkWidget *satconfig_locations_open (void);
 void satconfig_locations_cancel (void);
 void satconfig_locations_finish (void);
