@@ -2,7 +2,7 @@
 /*
   satlist-single-aos.c:  Helper functions accompaning satlist.c
 
-  Copyright (C)  2002-2003   Alexandru Csete.
+  Copyright (C)  2002-2005   Alexandru Csete.
 
   Authors:  Alexandru Csete <csete@users.sourceforge.net>
 
@@ -53,11 +53,11 @@ extern qth_struc qth;    /* defined in qth.c */
 extern GConfClient *client; /* main.c */
 
 /* private function prototypes */
-static void satlist_single_aos_print_cb (GtkWidget *, gpointer);
-static void satlist_single_aos_plot_cb (GtkWidget *, gpointer);
-static void satlist_single_aos_save_cb (GtkWidget *, gpointer);
-static void satlist_single_aos_save_save (GtkFileSelection *, gpointer);
-static void satlist_single_aos_close_cb (GtkWidget *, gpointer);
+static void satlist_single_aos_print_cb  (GtkWidget *, gpointer);
+static void satlist_single_aos_plot_cb   (GtkWidget *, gpointer);
+static void satlist_single_aos_save_cb   (GtkWidget *, gpointer);
+static void satlist_single_aos_save_save (GtkButton *, gpointer);
+static void satlist_single_aos_close_cb  (GtkWidget *, gpointer);
 
 
 
@@ -73,7 +73,7 @@ void satlist_single_aos_cb (GtkWidget *button, gpointer clist)
 	sat_t *sat;
 	guint index,n,i,row,step,orbit,bit,bitmask,listwidth=0;
 	gchar **vbuff,*buff,**detlist;
-	gchar *titles[9] = { N_(" Time (UTC) "),
+	gchar *titles[9] = { N_(" Time"),
 			     N_(" Az "), N_(" El "), N_(" Lat "), N_(" Lon "),
 			     N_(" Alt "), N_(" Range "), N_(" Vel "), N_(" Footprint ")	};
 
@@ -178,14 +178,13 @@ void satlist_single_aos_cb (GtkWidget *button, gpointer clist)
 						     GTK_SIGNAL_FUNC (satlist_single_aos_close_cb),
 						     dialog);
 			
-			/* disable unavailable features */
-			//			gnome_dialog_set_sensitive (GNOME_DIALOG (dialog), 0, FALSE);
 			/* "Close" is the default button */
 			gnome_dialog_set_default (GNOME_DIALOG (dialog), 3);
 
 			/* This will (?) automatically free the memory occupied by slist,
 			   when the dialog is closed. */
 			gtk_object_set_data_full (GTK_OBJECT (dialog), "list", detlist, free_vector_notify_cb);
+
 			/* Also add satellite index - needed for list title when printing from
 			   several open dialogs. */
 			gtk_object_set_data (GTK_OBJECT (dialog), "index", GUINT_TO_POINTER (index));
@@ -209,16 +208,17 @@ void satlist_single_aos_cb (GtkWidget *button, gpointer clist)
 static void
 satlist_single_aos_print_cb (GtkWidget *widget, gpointer data)
 {
-	guint index,n;
+	guint index,n,orbit;
 	sat_t *sat;
 	gchar **detlist;
 
-	detlist = gtk_object_get_data (GTK_OBJECT (data), "list" );
-	n = GPOINTER_TO_UINT (gtk_object_get_data (GTK_OBJECT (data), "size") );
-	index = GPOINTER_TO_UINT ( gtk_object_get_data (GTK_OBJECT (data), "index") );
+	detlist = gtk_object_get_data (GTK_OBJECT (data), "list");
+	n = GPOINTER_TO_UINT (gtk_object_get_data (GTK_OBJECT (data), "size"));
+	orbit = GPOINTER_TO_UINT (gtk_object_get_data (GTK_OBJECT (data), "orbit"));
+	index = GPOINTER_TO_UINT ( gtk_object_get_data (GTK_OBJECT (data), "index"));
 	sat = satdata_get_sat (index);
 
-	sat_print_aos_det (sat, detlist, n);
+	sat_print_aos_det (sat, detlist, n, orbit);
 }
 
 
@@ -259,12 +259,21 @@ satlist_single_aos_save_cb (GtkWidget *widget, gpointer data )
 	GtkWidget *filesel;
 
 	filesel = gtk_file_selection_new (_("Select a filename"));
+
+	/* attach satellite data to file selector, so that it can be passed to the save_save function */
+	gtk_object_set_data (GTK_OBJECT (filesel), "index", gtk_object_get_data (data, "index"));
+	gtk_object_set_data (GTK_OBJECT (filesel), "size", gtk_object_get_data (data, "size"));
+	gtk_object_set_data (GTK_OBJECT (filesel), "satname", gtk_object_get_data (data, "satname"));
+	gtk_object_set_data (GTK_OBJECT (filesel), "orbit", gtk_object_get_data (data, "orbit"));
+	gtk_object_set_data (GTK_OBJECT (filesel), "list", gtk_object_get_data (data, "list"));
+
 	/* set default path if exists */
-	if (gconf_client_get_string (client, AOS_DETAIL_SAVE_PATH, NULL) )
+	if (gconf_client_get_string (client, AOS_DETAIL_SAVE_PATH, NULL)) {
 		gtk_file_selection_set_filename (GTK_FILE_SELECTION (filesel),
-						 gnome_config_get_string (AOS_DETAIL_SAVE_PATH) );
+						 gconf_client_get_string (client, AOS_DETAIL_SAVE_PATH, NULL));
+	}
 	gtk_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION (filesel)->ok_button),
-			    "clicked", GTK_SIGNAL_FUNC (satlist_single_aos_save_save), data);
+			    "clicked", GTK_SIGNAL_FUNC (satlist_single_aos_save_save), (gpointer) filesel);
                              
 	/* Ensure that the dialog box is destroyed when the user clicks a button. */
 	gtk_signal_connect_object (GTK_OBJECT (GTK_FILE_SELECTION (filesel)->ok_button),
@@ -273,13 +282,14 @@ satlist_single_aos_save_cb (GtkWidget *widget, gpointer data )
 	gtk_signal_connect_object (GTK_OBJECT (GTK_FILE_SELECTION (filesel)->cancel_button),
 				   "clicked", GTK_SIGNAL_FUNC (gtk_widget_destroy),
 				   (gpointer) filesel);
+
 	gtk_widget_show (filesel);
 
 }
 
 
 static void
-satlist_single_aos_save_save (GtkFileSelection *fsel, gpointer data)
+satlist_single_aos_save_save (GtkButton *button, gpointer data)
 {
 	/* This function is called by the above function, and
 	   it calls the general data file saving function in
@@ -297,14 +307,13 @@ satlist_single_aos_save_save (GtkFileSelection *fsel, gpointer data)
 	/* get the data to be saved */
 	slist = gtk_object_get_data (GTK_OBJECT (data), "list");
 	n = GPOINTER_TO_UINT (gtk_object_get_data (GTK_OBJECT (data), "size"));
-/*	orbit = GPOINTER_TO_UINT (gtk_object_get_data (GTK_OBJECT (data), "orbit"));*/
-	fname = gtk_file_selection_get_filename (GTK_FILE_SELECTION(fsel));
+	fname = gtk_file_selection_get_filename (GTK_FILE_SELECTION(data));
 	if ( !g_file_test (fname, G_FILE_TEST_ISDIR) ) {
 		/* create header */
 		header = g_strdup_printf (_("Detailed pass information for %s orbit %d\n"\
 					    "%s %.2f%c %.2f%c\n"\
 					    "--------------------------------------------------------------------\n"\
-					    " Time (UTC)              Az        El       Lat       Lon     Alt\n"\
+					    " Time                    Az        El       Lat       Lon     Alt\n"\
 					    "--------------------------------------------------------------------\n"),
 					  (gchar *)gtk_object_get_data (GTK_OBJECT (data), "satname"),
 					  GPOINTER_TO_UINT (gtk_object_get_data (GTK_OBJECT (data), "orbit")), 
@@ -345,7 +354,7 @@ void satlist_single_aos_from_multi (sat_t *sat, gdouble aos)
 /*	sat_t *sat;*/
 	guint n,i,step,orbit,bit,bitmask,listwidth=0;
 	gchar **vbuff,*buff,**detlist;
-	gchar *titles[9] = { N_(" Time (UTC) "),
+	gchar *titles[9] = { N_(" Time"),
 			     N_(" Az "), N_(" El "), N_(" Lat "), N_(" Lon "),
 			     N_(" Alt "), N_(" Range "), N_(" Vel "), N_(" Footprint ")	};
 
