@@ -4,7 +4,7 @@
              selected satellites in a list.
 
 
-  Copyright (C)  2001-2003  Alexandru Csete.
+  Copyright (C)  2001-2005  Alexandru Csete.
 
   Authors:  Alexandru Csete <csete@users.sourceforge.net>
 
@@ -42,6 +42,7 @@
 #include "sattabs.h"
 #include "satmodules.h"
 #include "iconbar.h"
+#include "extra-widgets.h"
 #include "satlist-druid.h"
 #include "satlist-info.h"
 #include "satlist-single-aos.h"
@@ -89,28 +90,27 @@ extern qth_struc qth;    /* defined in qth.c */
 
 
 /* Private function protos */
-static void      satlist_rows_adjust     (GtkWidget *);
-static gint      satlist_sat_prepend     (GtkWidget *, guint);
-static gint      satlist_sat_prepend     (GtkWidget *, guint);
-static gint      satlist_sat_append      (GtkWidget *, guint);
-static gint      satlist_sat_insert      (GtkWidget *, gint, guint);
-static void      satlist_sat_remove      (GtkWidget *, gint);
-static void      satlist_update_visibles (GtkWidget *);
-static void      satlist_clear           (GtkWidget *);
-static void      satlist_read_list       (GtkWidget *, gchar *);
-static gint      satlist_get_size        (GtkWidget *);
-static gboolean  satlist_sat_is_visible  (GtkWidget *, gint);
-static gchar    *satlist_get_satname     (GtkWidget *, gint);
-static void      satlist_switch_mode_cb  (GtkWidget *, GtkWidget *);
-static void      satlist_close_cb        (GtkWidget *, GtkWidget *);
-static void      satlist_close_cleanup   (GtkWidget *);
-static gint      satlist_timer_cb        (gpointer);
-static gint      satlistwin_delete_cb    (GtkWidget *, GdkEvent *, GtkWidget *);
-static void      satlistwin_close_cb     (GtkWidget *, GtkWidget *);
-static gint      satlist_comp_func       (GtkCList *, gconstpointer, gconstpointer);
-static void      satlist_sort            (GtkCList *, gint, gpointer);
-static void      satlist_read_colors     (gpointer);
-static void      satlist_prefs_changed   (GConfClient *, guint, GConfEntry *, gpointer);
+static void      satlist_rows_adjust       (GtkWidget *);
+/* static gint      satlist_sat_prepend       (GtkWidget *, guint); */
+static gint      satlist_sat_append        (GtkWidget *, guint);
+/* static gint      satlist_sat_insert        (GtkWidget *, gint, guint); */
+static void      satlist_sat_remove        (GtkWidget *, gint);
+static void      satlist_update_visibles   (GtkWidget *);
+/* static void      satlist_clear             (GtkWidget *); */
+static void      satlist_read_list         (GtkWidget *, gchar *);
+static gint      satlist_get_size          (GtkWidget *);
+/* static gboolean  satlist_sat_is_visible    (GtkWidget *, gint); */
+static void      satlist_switch_mode_cb    (GtkWidget *, GtkWidget *);
+static void      satlist_close_cb          (GtkWidget *, GtkWidget *);
+static void      satlist_close_cleanup     (GtkWidget *);
+static gint      satlist_timer_cb          (gpointer);
+static gint      satlist_autosort_timer_cb (gpointer);
+static gint      satlistwin_delete_cb      (GtkWidget *, GdkEvent *, GtkWidget *);
+static void      satlistwin_close_cb       (GtkWidget *, GtkWidget *);
+static gint      satlist_comp_func         (GtkCList *, gconstpointer, gconstpointer);
+static void      satlist_sort              (GtkCList *, gint, gpointer);
+static void      satlist_read_colors       (gpointer);
+static void      satlist_prefs_changed     (GConfClient *, guint, GConfEntry *, gpointer);
 
 
 void satlist_open_cb (GtkWidget *widget, gpointer data)
@@ -135,11 +135,10 @@ gint satlist_open (gchar *name, gboolean addtolist)
 
 	/* Widgets */
 	GtkWidget *vbox,*buttonbox,*infobutton,*maosbutton,*saosbutton,*modebutton,*closebutton;
-	GtkWidget *satclist,*satswin,*pixmap;
-	GtkTooltips *kooltip;
-	gchar *menulabel,*pixmapfile;
+	GtkWidget *satclist,*satswin,*topbox;
+	gchar *menulabel;
 	guint i;
-	gint timer,delay;
+	gint timer,delay,sorttimer,sortdelay;
 	guint gconf_id;
 
 	/* Create a new list if none specified */
@@ -167,17 +166,18 @@ gint satlist_open (gchar *name, gboolean addtolist)
 	 	satmodules_add_module (name, SATMOD_TYPE_LIST);
 	}
 
+
 	/* get some config values */
 	delay = gconf_client_get_int (client, SATLIST_TIMER_PATH, NULL);
 	if (!delay)
 		delay = SATLIST_DEF_TIMER;
-
+	sortdelay = gconf_client_get_int (client, SATLIST_AUTOSORT_PATH, NULL);
 
 	/* create the clist widget */
 	satclist = gtk_clist_new_with_titles (COLUMNS, titles);
-	gtk_clist_column_titles_active (GTK_CLIST (satclist) );
-	gtk_clist_set_compare_func (GTK_CLIST (satclist), satlist_comp_func );
-	gtk_clist_set_sort_column (GTK_CLIST (satclist), 4 ); /* first click fix hack */
+	gtk_clist_column_titles_active (GTK_CLIST (satclist));
+	gtk_clist_set_compare_func (GTK_CLIST (satclist), satlist_comp_func);
+//	gtk_clist_set_sort_column (GTK_CLIST (satclist), 4); /* first click fix hack */
 	gtk_signal_connect (GTK_OBJECT (satclist), "click-column",
 			    GTK_SIGNAL_FUNC (satlist_sort), NULL);
 
@@ -207,63 +207,61 @@ gint satlist_open (gchar *name, gboolean addtolist)
 				   GTK_BUTTONBOX_START );
 
 	/* close button */
-	pixmapfile = g_strconcat ( PACKAGE_PIXMAPS_DIR, G_DIR_SEPARATOR_S, "icons",
-				   G_DIR_SEPARATOR_S, "cancel.png", NULL);
-	pixmap = gnome_pixmap_new_from_file (pixmapfile);
-	closebutton = gnome_pixmap_button (pixmap, _("  Close"));
-	g_free (pixmapfile);
-	kooltip = gtk_tooltips_new ();
-	gtk_tooltips_set_tip (kooltip, closebutton, _("Close this list"),
-			      NULL);
+	closebutton = gpredict_mini_button ("icons", "module-close.png", _("Close this list"));
+	gtk_button_set_relief (GTK_BUTTON (closebutton), GTK_RELIEF_NONE);
+
+	/* Clone button */
 
 	/* Tab/Win button */
-	pixmapfile = g_strconcat ( PACKAGE_PIXMAPS_DIR, G_DIR_SEPARATOR_S, "icons",
-				   G_DIR_SEPARATOR_S, "windows_small.png", NULL);
-	pixmap = gnome_pixmap_new_from_file (pixmapfile);
-	modebutton = gnome_pixmap_button (pixmap, _("  Mode"));
-	g_free (pixmapfile);
-	gtk_tooltips_set_tip (kooltip, modebutton, _("Switch betwen notebook and window mode"),
-			      NULL);
+	modebutton = gpredict_mini_button ("icons", "module-detach.png", _("Detach list from notebook"));
+	gtk_button_set_relief (GTK_BUTTON (modebutton), GTK_RELIEF_NONE);
 
 	/* satellite info button */
-	infobutton = gnome_pixmap_button (gnome_stock_pixmap_widget (app, GNOME_STOCK_PIXMAP_HELP),
-					  _("Sat Info") );
+	infobutton = gpredict_stock_pixmap_button (_("Info"), GNOME_STOCK_PIXMAP_HELP,
+						   _("Show Keplerian elements for the selected satellite"));
+
+/* 	infobutton = gpredict_pixmap_button (_(" Info"), "icons", "info.png", */
+/* 					     _("Show Keplerian elements for the selected satellite")); */
+
 	gtk_signal_connect (GTK_OBJECT (infobutton), "clicked",
 			    GTK_SIGNAL_FUNC (satlist_info_cb), satclist);
-	gtk_tooltips_set_tip (kooltip, infobutton, _("Show Keplerian elements for the selected satellite"),
-			      NULL);
 
 	/* Upcomming passes button */
-	maosbutton = gnome_pixmap_button (gnome_stock_pixmap_widget (app, GNOME_STOCK_PIXMAP_TIMER),
-					  "AOS/LOS" );
+	maosbutton = gpredict_stock_pixmap_button (_("AOS/LOS"), GNOME_STOCK_PIXMAP_TIMER,
+						   _("Show AOS and LOS times for upcoming passes"));
 	gtk_signal_connect (GTK_OBJECT (maosbutton), "clicked",
 			    GTK_SIGNAL_FUNC (satlist_multi_aos_cb), satclist);
-	gtk_tooltips_set_tip (kooltip, maosbutton, _("Show AOS and LOS times for upcoming passes"),
-			      NULL);
 
 	/* upcomming pass in details button */
-	saosbutton = gnome_pixmap_button (gnome_stock_pixmap_widget (app, GNOME_STOCK_PIXMAP_PROPERTIES),
-					  _("Next AOS") );
+	saosbutton = gpredict_stock_pixmap_button (_("Next AOS"), GNOME_STOCK_PIXMAP_PROPERTIES,
+						   _("Get detailed info about the upcoming pass"));
 	gtk_signal_connect (GTK_OBJECT (saosbutton), "clicked",
 			    GTK_SIGNAL_FUNC (satlist_single_aos_cb), satclist);
-	gtk_tooltips_set_tip (kooltip, saosbutton, _("Get detailed info about the upcoming pass"),
-			      NULL);
 
-	gtk_box_pack_start (GTK_BOX (buttonbox), GTK_WIDGET (closebutton), TRUE, TRUE, 0);
-	gtk_box_pack_start (GTK_BOX (buttonbox), GTK_WIDGET (modebutton), TRUE, TRUE, 0);
 	gtk_box_pack_start (GTK_BOX (buttonbox), GTK_WIDGET (infobutton), TRUE, TRUE, 0);
 	gtk_box_pack_start (GTK_BOX (buttonbox), GTK_WIDGET (maosbutton), TRUE, TRUE, 0);
 	gtk_box_pack_start (GTK_BOX (buttonbox), GTK_WIDGET (saosbutton), TRUE, TRUE, 0);
 
+	/* upper hbox to contain detach and close buttons */
+	topbox = gtk_hbox_new (FALSE, 0);
+	gtk_box_pack_end (GTK_BOX (topbox), closebutton, FALSE, FALSE, 0);
+	gtk_box_pack_end (GTK_BOX (topbox), modebutton, FALSE, FALSE, 0);
 
-	/* start timer */
+	/* start update timer */
 	timer = gtk_timeout_add (delay, satlist_timer_cb, satclist);
 
+
 	/* create a vertical box */
 	vbox = gtk_vbox_new (FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox), topbox, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (vbox), satswin, TRUE, TRUE, 0); /* extra space to swin */
 	gtk_box_pack_start (GTK_BOX (vbox), buttonbox, FALSE, FALSE, 0);
 
+	/* start autosort timer if non-zero */
+	if (sortdelay) {
+		sorttimer = gtk_timeout_add (1000*sortdelay, satlist_autosort_timer_cb, satclist);
+		gtk_object_set_data (GTK_OBJECT (vbox), "sorttimer", GINT_TO_POINTER (sorttimer));
+	}
 
 	/* attach stuff to vbox */
 	gtk_object_set_data (GTK_OBJECT (vbox), "name", name);
@@ -315,73 +313,73 @@ static void satlist_rows_adjust (GtkWidget *clist)
 }
 
 
-static gint satlist_sat_prepend (GtkWidget *clist, guint index)
-{
-	/* Function to prepend a new satellite into satclist widget.
-	 */
+/* static gint satlist_sat_prepend (GtkWidget *clist, guint index) */
+/* { */
+/* 	/\* Function to prepend a new satellite into satclist widget. */
+/* 	 *\/ */
 
-	gchar *buf,**text;
-	gint code;
-	sat_t *sat;
+/* 	gchar *buf,**text; */
+/* 	gint code; */
+/* 	sat_t *sat; */
 
-	sat = satdata_get_sat (index);
+/* 	sat = satdata_get_sat (index); */
 
-	switch (sat->status) {
-	case SAT_STATUS_DECAYED:
-		buf = g_strdup_printf (_("%s;%7.2f;%7.2f;%7.2f;%7.2f;-- DECAYED --;"\
-					 "%6.0f;%7.0f;%7.0f;%7.0f;%7ld"),
-				       sat->name,sat->lon,sat->lat,sat->az,sat->el,sat->fp,
-				       sat->range,sat->alt,sat->vel,sat->orbit);
-		text = g_strsplit (buf, ";", 12);
-		code = gtk_clist_prepend (GTK_CLIST (clist), text);
-		gtk_clist_set_row_data (GTK_CLIST (clist), code, GUINT_TO_POINTER (index) );
-		gtk_clist_set_foreground (GTK_CLIST (clist), code, &dec );
-		g_free (buf);
-		g_strfreev (text);
-		break;
-	case SAT_STATUS_GEOSTAT:
-		buf = g_strdup_printf (_("%s;%7.2f;%7.2f;%7.2f;%7.2f;GEOSTATIONARY;"\
-					 "%6.0f;%7.0f;%7.0f;%7.0f;%7ld"),
-				       sat->name,sat->lon,sat->lat,sat->az,sat->el,sat->fp,
-				       sat->range,sat->alt,sat->vel,sat->orbit);
-		text = g_strsplit (buf, ";", 12);
-		code = gtk_clist_prepend (GTK_CLIST (clist), text);
-		gtk_clist_set_row_data (GTK_CLIST (clist), code, GUINT_TO_POINTER (index) );
-		if (sat->el > 0)
-			gtk_clist_set_foreground (GTK_CLIST (clist), code, &geoh);
-		else
-			gtk_clist_set_foreground (GTK_CLIST (clist), code, &geon);
-		g_free (buf);
-		g_strfreev (text);
-		break;
-	case SAT_STATUS_NOAOS:
-		buf = g_strdup_printf (_("%s;%7.2f;%7.2f;%7.2f;%7.2f;--- NEVER ---;"\
-					 "%6.0f;%7.0f;%7.0f;%7.0f;%7ld"),
-				       sat->name,sat->lon,sat->lat,sat->az,sat->el,sat->fp,
-				       sat->range,sat->alt,sat->vel,sat->orbit);
-		text = g_strsplit (buf, ";", 12);
-		code = gtk_clist_prepend (GTK_CLIST (clist), text);
-		gtk_clist_set_row_data (GTK_CLIST (clist), code, GUINT_TO_POINTER (index));
-		gtk_clist_set_foreground (GTK_CLIST (clist), code, &noaos);
-		g_free (buf);
-		g_strfreev (text);
-		break;
-	default:
-		buf = g_strdup_printf ("%s;%7.2f;%7.2f;%7.2f;%7.2f; %s ;"\
-				       "%6.0f;%7.0f;%7.0f;%7.0f;%7ld",
-				       sat->name, sat->lon, sat->lat, sat->az, sat->el,
-				       (sat->el > 0) ? dnum2str (sat->los) : dnum2str (sat->aos),
-				       sat->fp, sat->range, sat->alt, sat->vel, sat->orbit);
-		text = g_strsplit (buf, ";", 12);
-		code = gtk_clist_prepend (GTK_CLIST (clist), text);
-		gtk_clist_set_row_data (GTK_CLIST (clist), code, GUINT_TO_POINTER (index));
-		g_free (buf);
-		g_strfreev (text);
-		gtk_clist_set_foreground (GTK_CLIST (clist), code, (sat->el > 0) ? &high : &norm);
-	}
+/* 	switch (sat->status) { */
+/* 	case SAT_STATUS_DECAYED: */
+/* 		buf = g_strdup_printf (_("%s;%7.2f;%7.2f;%7.2f;%7.2f;-- DECAYED --;"\ */
+/* 					 "%6.0f;%7.0f;%7.0f;%7.0f;%7ld"), */
+/* 				       sat->name,sat->lon,sat->lat,sat->az,sat->el,sat->fp, */
+/* 				       sat->range,sat->alt,sat->vel,sat->orbit); */
+/* 		text = g_strsplit (buf, ";", 12); */
+/* 		code = gtk_clist_prepend (GTK_CLIST (clist), text); */
+/* 		gtk_clist_set_row_data (GTK_CLIST (clist), code, GUINT_TO_POINTER (index) ); */
+/* 		gtk_clist_set_foreground (GTK_CLIST (clist), code, &dec ); */
+/* 		g_free (buf); */
+/* 		g_strfreev (text); */
+/* 		break; */
+/* 	case SAT_STATUS_GEOSTAT: */
+/* 		buf = g_strdup_printf (_("%s;%7.2f;%7.2f;%7.2f;%7.2f;GEOSTATIONARY;"\ */
+/* 					 "%6.0f;%7.0f;%7.0f;%7.0f;%7ld"), */
+/* 				       sat->name,sat->lon,sat->lat,sat->az,sat->el,sat->fp, */
+/* 				       sat->range,sat->alt,sat->vel,sat->orbit); */
+/* 		text = g_strsplit (buf, ";", 12); */
+/* 		code = gtk_clist_prepend (GTK_CLIST (clist), text); */
+/* 		gtk_clist_set_row_data (GTK_CLIST (clist), code, GUINT_TO_POINTER (index) ); */
+/* 		if (sat->el > 0) */
+/* 			gtk_clist_set_foreground (GTK_CLIST (clist), code, &geoh); */
+/* 		else */
+/* 			gtk_clist_set_foreground (GTK_CLIST (clist), code, &geon); */
+/* 		g_free (buf); */
+/* 		g_strfreev (text); */
+/* 		break; */
+/* 	case SAT_STATUS_NOAOS: */
+/* 		buf = g_strdup_printf (_("%s;%7.2f;%7.2f;%7.2f;%7.2f;--- NEVER ---;"\ */
+/* 					 "%6.0f;%7.0f;%7.0f;%7.0f;%7ld"), */
+/* 				       sat->name,sat->lon,sat->lat,sat->az,sat->el,sat->fp, */
+/* 				       sat->range,sat->alt,sat->vel,sat->orbit); */
+/* 		text = g_strsplit (buf, ";", 12); */
+/* 		code = gtk_clist_prepend (GTK_CLIST (clist), text); */
+/* 		gtk_clist_set_row_data (GTK_CLIST (clist), code, GUINT_TO_POINTER (index)); */
+/* 		gtk_clist_set_foreground (GTK_CLIST (clist), code, &noaos); */
+/* 		g_free (buf); */
+/* 		g_strfreev (text); */
+/* 		break; */
+/* 	default: */
+/* 		buf = g_strdup_printf ("%s;%7.2f;%7.2f;%7.2f;%7.2f; %s ;"\ */
+/* 				       "%6.0f;%7.0f;%7.0f;%7.0f;%7ld", */
+/* 				       sat->name, sat->lon, sat->lat, sat->az, sat->el, */
+/* 				       (sat->el > 0) ? dnum2str (sat->los) : dnum2str (sat->aos), */
+/* 				       sat->fp, sat->range, sat->alt, sat->vel, sat->orbit); */
+/* 		text = g_strsplit (buf, ";", 12); */
+/* 		code = gtk_clist_prepend (GTK_CLIST (clist), text); */
+/* 		gtk_clist_set_row_data (GTK_CLIST (clist), code, GUINT_TO_POINTER (index)); */
+/* 		g_free (buf); */
+/* 		g_strfreev (text); */
+/* 		gtk_clist_set_foreground (GTK_CLIST (clist), code, (sat->el > 0) ? &high : &norm); */
+/* 	} */
 
-	return code;
-}
+/* 	return code; */
+/* } */
 
 
 static gint satlist_sat_append (GtkWidget *clist, guint index)
@@ -454,73 +452,73 @@ static gint satlist_sat_append (GtkWidget *clist, guint index)
 
 
 
-static gint satlist_sat_insert (GtkWidget *clist, gint row, guint index)
-{
-	/* Function to insert a new satellite into 
-	   the satclist widget at the specified position.
-	*/
+/* static gint satlist_sat_insert (GtkWidget *clist, gint row, guint index) */
+/* { */
+/* 	/\* Function to insert a new satellite into  */
+/* 	   the satclist widget at the specified position. */
+/* 	*\/ */
 
-	gchar *buf,**text;
-	gint code;
-	sat_t *sat;
+/* 	gchar *buf,**text; */
+/* 	gint code; */
+/* 	sat_t *sat; */
 
-	sat = satdata_get_sat (index);
-	switch (sat->status) {
-	case SAT_STATUS_DECAYED:
-		buf = g_strdup_printf (_("%s;%7.2f;%7.2f;%7.2f;%7.2f;-- DECAYED --;"\
-					 "%6.0f;%7.0f;%7.0f;%7.0f;%7ld"),
-				       sat->name,sat->lon,sat->lat,sat->az,sat->el,sat->fp,
-				       sat->range,sat->alt,sat->vel,sat->orbit);
-		text = g_strsplit (buf, ";", 12);
-		code = gtk_clist_insert (GTK_CLIST (clist), row, text);
-		gtk_clist_set_row_data (GTK_CLIST (clist), code, GUINT_TO_POINTER (index));
-		gtk_clist_set_foreground (GTK_CLIST (clist), code, &dec);
-		g_free (buf);
-		g_strfreev (text);
-		break;
-	case SAT_STATUS_GEOSTAT:
-		buf = g_strdup_printf (_("%s;%7.2f;%7.2f;%7.2f;%7.2f;GEOSTATIONARY;"\
-					 "%6.0f;%7.0f;%7.0f;%7.0f;%7ld"),
-				       sat->name,sat->lon,sat->lat,sat->az,sat->el,sat->fp,
-				       sat->range,sat->alt,sat->vel,sat->orbit);
-		text = g_strsplit (buf, ";", 12);
-		code = gtk_clist_insert (GTK_CLIST (clist), row, text);
-		gtk_clist_set_row_data (GTK_CLIST (clist), code, GUINT_TO_POINTER (index));
-		if ( sat->el>0 )
-			gtk_clist_set_foreground (GTK_CLIST (clist), code, &geoh);
-		else
-			gtk_clist_set_foreground (GTK_CLIST (clist), code, &geon);
-		g_free (buf);
-		g_strfreev (text);
-		break;
-	case SAT_STATUS_NOAOS:
-		buf = g_strdup_printf (_("%s;%7.2f;%7.2f;%7.2f;%7.2f;--- NEVER ---;"\
-					 "%6.0f;%7.0f;%7.0f;%7.0f;%7ld"),
-				       sat->name,sat->lon,sat->lat,sat->az,sat->el,sat->fp,
-				       sat->range,sat->alt,sat->vel,sat->orbit);
-		text = g_strsplit (buf, ";", 12);
-		code = gtk_clist_insert (GTK_CLIST (clist), row, text);
-		gtk_clist_set_row_data (GTK_CLIST (clist), code, GUINT_TO_POINTER (index));
-		gtk_clist_set_foreground (GTK_CLIST (clist), code, &noaos);
-		g_free (buf);
-		g_strfreev (text);
-		break;
-	default:
-		buf = g_strdup_printf ("%s;%7.2f;%7.2f;%7.2f;%7.2f; %s ;"\
-				       "%6.0f;%7.0f;%7.0f;%7.0f;%7ld",
-				       sat->name, sat->lon, sat->lat, sat->az, sat->el,
-				       (sat->el > 0) ? dnum2str (sat->los) : dnum2str (sat->aos),
-				       sat->fp, sat->range, sat->alt, sat->vel, sat->orbit);
-		text = g_strsplit (buf, ";", 12);
-		code = gtk_clist_insert (GTK_CLIST (clist), row, text);
-		gtk_clist_set_row_data (GTK_CLIST (clist), code, GUINT_TO_POINTER (index));
-		g_free (buf);
-		g_strfreev (text);
-		gtk_clist_set_foreground (GTK_CLIST (clist), code, (sat->el > 0) ? &high : &norm);
-	}
+/* 	sat = satdata_get_sat (index); */
+/* 	switch (sat->status) { */
+/* 	case SAT_STATUS_DECAYED: */
+/* 		buf = g_strdup_printf (_("%s;%7.2f;%7.2f;%7.2f;%7.2f;-- DECAYED --;"\ */
+/* 					 "%6.0f;%7.0f;%7.0f;%7.0f;%7ld"), */
+/* 				       sat->name,sat->lon,sat->lat,sat->az,sat->el,sat->fp, */
+/* 				       sat->range,sat->alt,sat->vel,sat->orbit); */
+/* 		text = g_strsplit (buf, ";", 12); */
+/* 		code = gtk_clist_insert (GTK_CLIST (clist), row, text); */
+/* 		gtk_clist_set_row_data (GTK_CLIST (clist), code, GUINT_TO_POINTER (index)); */
+/* 		gtk_clist_set_foreground (GTK_CLIST (clist), code, &dec); */
+/* 		g_free (buf); */
+/* 		g_strfreev (text); */
+/* 		break; */
+/* 	case SAT_STATUS_GEOSTAT: */
+/* 		buf = g_strdup_printf (_("%s;%7.2f;%7.2f;%7.2f;%7.2f;GEOSTATIONARY;"\ */
+/* 					 "%6.0f;%7.0f;%7.0f;%7.0f;%7ld"), */
+/* 				       sat->name,sat->lon,sat->lat,sat->az,sat->el,sat->fp, */
+/* 				       sat->range,sat->alt,sat->vel,sat->orbit); */
+/* 		text = g_strsplit (buf, ";", 12); */
+/* 		code = gtk_clist_insert (GTK_CLIST (clist), row, text); */
+/* 		gtk_clist_set_row_data (GTK_CLIST (clist), code, GUINT_TO_POINTER (index)); */
+/* 		if ( sat->el>0 ) */
+/* 			gtk_clist_set_foreground (GTK_CLIST (clist), code, &geoh); */
+/* 		else */
+/* 			gtk_clist_set_foreground (GTK_CLIST (clist), code, &geon); */
+/* 		g_free (buf); */
+/* 		g_strfreev (text); */
+/* 		break; */
+/* 	case SAT_STATUS_NOAOS: */
+/* 		buf = g_strdup_printf (_("%s;%7.2f;%7.2f;%7.2f;%7.2f;--- NEVER ---;"\ */
+/* 					 "%6.0f;%7.0f;%7.0f;%7.0f;%7ld"), */
+/* 				       sat->name,sat->lon,sat->lat,sat->az,sat->el,sat->fp, */
+/* 				       sat->range,sat->alt,sat->vel,sat->orbit); */
+/* 		text = g_strsplit (buf, ";", 12); */
+/* 		code = gtk_clist_insert (GTK_CLIST (clist), row, text); */
+/* 		gtk_clist_set_row_data (GTK_CLIST (clist), code, GUINT_TO_POINTER (index)); */
+/* 		gtk_clist_set_foreground (GTK_CLIST (clist), code, &noaos); */
+/* 		g_free (buf); */
+/* 		g_strfreev (text); */
+/* 		break; */
+/* 	default: */
+/* 		buf = g_strdup_printf ("%s;%7.2f;%7.2f;%7.2f;%7.2f; %s ;"\ */
+/* 				       "%6.0f;%7.0f;%7.0f;%7.0f;%7ld", */
+/* 				       sat->name, sat->lon, sat->lat, sat->az, sat->el, */
+/* 				       (sat->el > 0) ? dnum2str (sat->los) : dnum2str (sat->aos), */
+/* 				       sat->fp, sat->range, sat->alt, sat->vel, sat->orbit); */
+/* 		text = g_strsplit (buf, ";", 12); */
+/* 		code = gtk_clist_insert (GTK_CLIST (clist), row, text); */
+/* 		gtk_clist_set_row_data (GTK_CLIST (clist), code, GUINT_TO_POINTER (index)); */
+/* 		g_free (buf); */
+/* 		g_strfreev (text); */
+/* 		gtk_clist_set_foreground (GTK_CLIST (clist), code, (sat->el > 0) ? &high : &norm); */
+/* 	} */
 
-	return code;
-}
+/* 	return code; */
+/* } */
 
 
 static void satlist_sat_remove (GtkWidget *clist, gint row)
@@ -576,6 +574,7 @@ static void satlist_update_visibles (GtkWidget *clist)
 				gtk_clist_set_text (GTK_CLIST (clist), i, 2, tmp[1]);
 				gtk_clist_set_text (GTK_CLIST (clist), i, 3, tmp[2]);
 				gtk_clist_set_text (GTK_CLIST (clist), i, 4, tmp[3]);
+				gtk_clist_set_text (GTK_CLIST (clist), i, 5, (sat->el > 0) ? dnum2str (sat->los) : dnum2str (sat->aos));
 				gtk_clist_set_text (GTK_CLIST (clist), i, 6, tmp[4]);
 				gtk_clist_set_text (GTK_CLIST (clist), i, 7, tmp[5]);
 				gtk_clist_set_text (GTK_CLIST (clist), i, 8, tmp[6]);
@@ -591,14 +590,14 @@ static void satlist_update_visibles (GtkWidget *clist)
 
 
 
-static void satlist_clear (GtkWidget *clist)
-{
-	/* Function to quick and dirty removal of ALL satellites from
-	   the sat_l. Well, maybe not dirty after all...
-	*/
-//	rowsel = -1;
-	gtk_clist_clear (GTK_CLIST (clist));
-}
+/* static void satlist_clear (GtkWidget *clist) */
+/* { */
+/* 	/\* Function to quick and dirty removal of ALL satellites from */
+/* 	   the sat_l. Well, maybe not dirty after all... */
+/* 	*\/ */
+/* //	rowsel = -1; */
+/* 	gtk_clist_clear (GTK_CLIST (clist)); */
+/* } */
 
 
 
@@ -663,28 +662,11 @@ static gint satlist_get_size (GtkWidget *clist)
 
 
 
-static gboolean satlist_sat_is_visible (GtkWidget *clist, gint row)
-{
-	/* Is the row visible? */
-	return gtk_clist_row_is_visible (GTK_CLIST (clist), row);
-}
-
-
-
-static gchar *satlist_get_satname (GtkWidget *clist, gint row)
-{	
-	/* The gtk_clist_get_text function needs a pointer to a
-	   pointer to store the text in..
-	   The function returns 1 on succes, 0 otherwise.
-	*/
-
-	/**** FIXME: THIS FUNCTION IS OBSOLETE! */
-	return NULL;
-/*  	if ( gtk_clist_get_text (GTK_CLIST (clist), row, 0, &tmp)) */
-/*  		return tmp; */
-/*  	else */
-/*  		return NULL; */
-}
+/* static gboolean satlist_sat_is_visible (GtkWidget *clist, gint row) */
+/* { */
+/* 	/\* Is the row visible? *\/ */
+/* 	return gtk_clist_row_is_visible (GTK_CLIST (clist), row); */
+/* } */
 
 
 
@@ -703,52 +685,102 @@ satlist_switch_mode_cb (GtkWidget *button, GtkWidget *vbox)
 	gchar *name,*menulabel,*buff;
 	gint page;
 	GtkWidget *satwin;
+	GtkWidget   *pixmap;
+	gchar       *pixmappath;
+	GtkTooltips *tips;
 
 	mode = GPOINTER_TO_UINT (gtk_object_get_data (GTK_OBJECT (vbox), "mode"));
 	name = gtk_object_get_data (GTK_OBJECT (vbox), "name");
+
 	switch (mode) {
+
 	case SATLIST_MODE_TAB:
 		page = sattabs_lookup_tab (vbox);
 		if (page != -1) {
+
 			/* delete from notebook */
 			gtk_widget_ref (vbox);
 			sattabs_remove_tab (page);
+
 			/* update state */
 			gtk_object_set_data (GTK_OBJECT (vbox), "mode",
 					     GUINT_TO_POINTER (SATLIST_MODE_WIN));
+
 			/* create window */
 			satwin = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 			gtk_object_set_data (GTK_OBJECT (vbox), "window", satwin);
 			gtk_window_set_title (GTK_WINDOW (satwin), name);
+			gtk_widget_set_usize (satwin, 640, 400);
+
 			/* try to set window size to something sensible */
 			/* window icon */
 			buff = g_strconcat (PACKAGE_PIXMAPS_DIR, "/icons/satlist.png", NULL);
 			gnome_window_icon_set_from_file (GTK_WINDOW (satwin), buff);
 			g_free (buff);
+
 			/* connect window signals */
 			gtk_signal_connect (GTK_OBJECT (satwin), "delete-event",
 					    GTK_SIGNAL_FUNC (satlistwin_delete_cb), vbox);
 			gtk_signal_connect (GTK_OBJECT (satwin), "destroy",
 					    GTK_SIGNAL_FUNC (satlistwin_close_cb), vbox);
 			gtk_container_add (GTK_CONTAINER (satwin), vbox);
+
+			/* change icon to attach */
+			pixmap = GTK_WIDGET (gtk_object_get_data (GTK_OBJECT (button), "pixmap"));
+			gtk_container_remove (GTK_CONTAINER (button), pixmap);
+			gtk_object_remove_data (GTK_OBJECT (button), "pixmap");
+			pixmappath = g_strconcat (PACKAGE_PIXMAPS_DIR, G_DIR_SEPARATOR_S, "icons",
+						  G_DIR_SEPARATOR_S, "module-attach.png", NULL);
+			pixmap = gnome_pixmap_new_from_file (pixmappath);
+			gtk_container_add (GTK_CONTAINER (button), pixmap);
+			gtk_object_set_data (GTK_OBJECT (button), "pixmap", pixmap);
+			g_free (pixmappath);
+
+			tips = gtk_tooltips_new ();
+			gtk_tooltips_set_tip (tips, button,
+					      _("Attach list to notebook"), NULL);
+
 			gtk_widget_show_all (satwin);
 		}
 		break;
+
 	case SATLIST_MODE_WIN:
+
 		/* get and destroy the window */
 		satwin = gtk_object_get_data (GTK_OBJECT (vbox), "window");
 		gtk_object_remove_data (GTK_OBJECT (vbox), "window");
 		gtk_container_remove (GTK_CONTAINER (satwin), vbox);
 		gtk_widget_destroy (satwin);
+
 		/* reconfigure module */
 		gtk_object_set_data (GTK_OBJECT (vbox), "mode",
 				     GUINT_TO_POINTER (SATLIST_MODE_TAB));
 		menulabel = g_strconcat (name, _(" (list)"), NULL);
 		sattabs_add_tab_menu (vbox, name, menulabel);
 		g_free (menulabel);
+
+		/* change icon to detach */
+		pixmap = GTK_WIDGET (gtk_object_get_data (GTK_OBJECT (button), "pixmap"));
+		gtk_container_remove (GTK_CONTAINER (button), pixmap);
+		gtk_object_remove_data (GTK_OBJECT (button), "pixmap");
+		pixmappath = g_strconcat (PACKAGE_PIXMAPS_DIR, G_DIR_SEPARATOR_S, "icons",
+					  G_DIR_SEPARATOR_S, "module-detach.png", NULL);
+		pixmap = gnome_pixmap_new_from_file (pixmappath);
+		gtk_container_add (GTK_CONTAINER (button), pixmap);
+		gtk_object_set_data (GTK_OBJECT (button), "pixmap", pixmap);
+		g_free (pixmappath);
+
+		tips = gtk_tooltips_new ();
+		gtk_tooltips_set_tip (tips, button,
+				      _("Detach map from notebook"), NULL);
+
+		gtk_widget_show_all (button);
+
 		break;
+
 	case SATLIST_MODE_FULLSCR:
 		break;
+
 	default:
 		satlog_log (SAT_LOG_CRITICAL, _("SATLIST: Invalid mode (BUG!)"));
 	}
@@ -763,6 +795,7 @@ gint satlistwin_delete_cb (GtkWidget *widget, GdkEvent *event, GtkWidget *vbox)
 	   will be destroyed, ie. the next function will be called.
 	*/
 	satlist_close_cb (NULL, vbox);
+
 	return FALSE;
 }
 
@@ -799,6 +832,10 @@ satlist_close_cb (GtkWidget *button, GtkWidget *vbox)
 	gconf_client_notify_remove (client,
 				    GPOINTER_TO_UINT (gtk_object_get_data (GTK_OBJECT (vbox), "gconfid")));
 
+	/* also autosort, if running */
+	if (gtk_object_get_data (GTK_OBJECT (vbox), "sorttimer"))
+		gtk_timeout_remove (GPOINTER_TO_INT (gtk_object_get_data (GTK_OBJECT (vbox), "sorttimer")));
+
 	module = g_strdup (gtk_object_get_data (GTK_OBJECT (vbox), "name"));
 	/* add icon to iconbar */
 	iconbar_add_module (module, SATMOD_TYPE_LIST);
@@ -845,6 +882,21 @@ satlist_timer_cb (gpointer clist)
 	gtk_clist_freeze (GTK_CLIST (clist));
 	satlist_update_visibles (clist);
 	gtk_clist_thaw (GTK_CLIST (clist));
+
+	return TRUE;
+}
+
+
+static gint
+satlist_autosort_timer_cb (gpointer clist)
+{
+	/* This function is used to automatically trigger
+	   the clist_sort function at regular intervals so
+	   that the satellite list is kept sorted at any times.
+	*/
+
+	satlist_sort (GTK_CLIST (clist), -1, NULL);
+
 	return TRUE;
 }
 
@@ -885,16 +937,21 @@ satlist_comp_func (GtkCList *clist, gconstpointer s1, gconstpointer s2)
 static void
 satlist_sort (GtkCList *clist, gint column, gpointer data)
 {
-	/* Column sorting function */
+	/* Column sorting function. If column is -1, the present sort column
+	   is kept.
+	 */
 	/**** WARNING: The global sat_l has been changed to clist param */
 
-	gnome_app_flash (GNOME_APP (app), _("Sorting list"));
-	if ( column == GTK_CLIST (clist)->sort_column ) {
-		/* flip sorting mode (ascend/descend)  */
-		gtk_clist_set_sort_type (GTK_CLIST (clist),
-					 !GTK_CLIST (clist)->sort_type );
-	} else {
-		gtk_clist_set_sort_column (GTK_CLIST (clist), column);
+	if (column != -1) {
+		/* user clicked on a column title */
+		gnome_app_flash (GNOME_APP (app), _("Sorting list"));
+		if (column == GTK_CLIST (clist)->sort_column) {
+			/* flip sorting mode (ascend/descend)  */
+			gtk_clist_set_sort_type (GTK_CLIST (clist),
+						 !GTK_CLIST (clist)->sort_type );
+		} else {
+			gtk_clist_set_sort_column (GTK_CLIST (clist), column);
+		}
 	}
 	gtk_clist_freeze (GTK_CLIST (clist));
 	gtk_clist_sort (GTK_CLIST (clist));
@@ -1035,14 +1092,27 @@ satlist_prefs_changed (GConfClient *client, guint cid, GConfEntry *entry, gpoint
 	*/
 	gint delay,timer;
 
+	/* regular timer */
 	delay = gconf_client_get_int (client, SATLIST_TIMER_PATH, NULL);
 	if (!delay)
 		delay = SATLIST_DEF_TIMER;
 
 	gtk_timeout_remove (GPOINTER_TO_INT (gtk_object_get_data (GTK_OBJECT (vbox), "timer")));
-	satlist_read_colors (gtk_object_get_data (GTK_OBJECT (vbox), "clist"));
 	timer = gtk_timeout_add (delay, satlist_timer_cb,
 				 gtk_object_get_data (GTK_OBJECT (vbox), "clist"));
 	gtk_object_set_data (GTK_OBJECT (vbox), "timer", GINT_TO_POINTER (timer));
 
+	/* autosort timer */
+	delay = gconf_client_get_int (client, SATLIST_AUTOSORT_PATH, NULL);
+	if (delay) {
+		if (GPOINTER_TO_INT (gtk_object_get_data (GTK_OBJECT (vbox), "sorttimer")))
+			gtk_timeout_remove (GPOINTER_TO_INT (gtk_object_get_data (GTK_OBJECT (vbox),
+										  "sorttimer")));
+		timer = gtk_timeout_add (1000*delay, satlist_autosort_timer_cb,
+					 gtk_object_get_data (GTK_OBJECT (vbox), "clist"));
+		gtk_object_set_data (GTK_OBJECT (vbox), "sorttimer", GINT_TO_POINTER (timer));
+	}
+
+	satlist_read_colors (gtk_object_get_data (GTK_OBJECT (vbox), "clist"));
+
 }
