@@ -2,7 +2,7 @@
 /*
   satmap-druid.c: Tools and widgets to set up a new satmap.
 
-  Copyright (C)  2001-2003  Alexandru Csete.
+  Copyright (C)  2001-2005  Alexandru Csete.
 
   Authors: Alexandru Csete <csete@users.sourceforge.net>
 
@@ -66,6 +66,8 @@ static gchar *mapfile = NULL;
 
 static gchar *title2[1] = { N_("Shown Satellites") };
 
+static GtkWidget *dp = NULL; /* pointer to dialog */
+
 gchar *satmap_druid_run (const gchar *module)
 {
 	/* This function is called when satmap_open is invoked
@@ -266,6 +268,11 @@ gchar *satmap_druid_run (const gchar *module)
 				   GNOME_STOCK_BUTTON_OK,
 				   GNOME_STOCK_BUTTON_CANCEL,
 				   NULL );
+	gnome_dialog_set_parent (GNOME_DIALOG (dialog), GTK_WINDOW (app));
+
+	/* store global pointer */
+	dp = dialog;
+
 	gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (dialog)->vbox), table,
 			    TRUE, TRUE , 0);
 
@@ -516,7 +523,12 @@ satmap_druid_ok_cb (GtkWidget *widget, GtkCList *list2)
 		    GPOINTER_TO_UINT (gtk_object_get_data (GTK_OBJECT (list2), "newmod"))) {
 			gnome_app_error (GNOME_APP (app),
 					 _("There is already a map with that name!"));
+
+			/* clear file name */
 			g_free (name);
+			name = NULL;
+
+			/* clear config path */
 			g_free (configpath);
 			return;
 		}
@@ -525,6 +537,7 @@ satmap_druid_ok_cb (GtkWidget *widget, GtkCList *list2)
 		/* create vector to save */
 		argc = gtk_clist_append (list2, &dummy);
 		if (!argc) {
+
 			/* no satellites in list */
 			buff2 = g_strconcat (__FUNCTION__, _(": No satellites selected!"), NULL);
 			satlog_log (SAT_LOG_WARNING, buff2);
@@ -567,7 +580,7 @@ satmap_druid_ok_cb (GtkWidget *widget, GtkCList *list2)
 		GtkWidget *err;
 
 		err = gnome_warning_dialog (_("You did not enter a name!\n"\
-					      "The list has not been created!"));
+					      "The map has not been created!"));
 		gtk_widget_show_all (err);
 	}
 }
@@ -587,6 +600,45 @@ satmap_druid_update_clist_title (GtkCList *maplist, const gchar *text)
 	title = g_strdup_printf ("%s (%d)", text, count);
 	gtk_clist_set_column_title (maplist, 0, title);
 	g_free (title);
+
+	if (count > SATMAP_TOO_MANY_SATS) {
+		/* User wants too many satellites on the map. Isuue a warning!
+		   Yes, this could be done much simpler, but the simple solutions
+		   would not allow the warning dialog to have the mouse/keyboard
+		   focus, until the druid dialog is closed. Go figure...
+		*/
+		GtkWidget *dialog,*pixmap,*label,*hbox;
+		gchar *message;
+
+		message = g_strdup_printf (_("You have selected too many (%d)\n"
+					     "satellites for this map. You should\n"
+					     "not have more than %d satellites\n"
+					     "on the same map!"), count,
+					   SATMAP_TOO_MANY_SATS);
+		label = gtk_label_new (message);
+		gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_FILL);
+		g_free (message);
+
+		/* pixmap */
+		message = g_strconcat (PACKAGE_PIXMAPS_DIR, G_DIR_SEPARATOR_S, "icons",
+				       G_DIR_SEPARATOR_S, "crash.png", NULL);
+		pixmap = gnome_pixmap_new_from_file (message);
+		g_free (message);
+
+		/* horibox */
+		hbox = gtk_hbox_new (FALSE, 20);
+		gtk_box_pack_start_defaults (GTK_BOX (hbox), pixmap);
+		gtk_box_pack_start_defaults (GTK_BOX (hbox), label);
+		gtk_widget_show_all (hbox);
+
+
+		dialog = gnome_dialog_new (_("Warning"), GNOME_STOCK_BUTTON_OK, NULL);
+		gnome_dialog_set_parent (GNOME_DIALOG (dialog), GTK_WINDOW (dp));
+		gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (dialog)->vbox), 
+				    hbox, TRUE, TRUE, 0);
+		gnome_dialog_run_and_close (GNOME_DIALOG (dialog));
+	       
+	}
 }
 
 
