@@ -2,7 +2,7 @@
 /*
   satpref_qth.c:  Gnome Predict configuration module (locations).
 
-  Copyright (C)  2003  Alexandru Csete.
+  Copyright (C)  2001-2005  Alexandru Csete.
 
   Authors: Alexandru Csete <csete@users.sourceforge.net>
 
@@ -41,8 +41,10 @@
 #include "sat-ui-utils.h"
 #include "satlog.h"
 #include "satloc-tree.h"
+#include "satconfig-locations.h"
 
-#if defined (HAVE_LIBHAMLIB) && defined (HAVE_HAMLIB_ROTATOR_H)
+
+#if defined (HAVE_HAMLIB)
 #  include <hamlib/rotator.h>
 static void satpref_qth_latlon_cb         (GtkAdjustment *adj, gpointer data);
 static void satpref_qth_latlon_toggled_cb (GtkToggleButton *button, gpointer locbut);
@@ -250,6 +252,7 @@ satpref_qth_apply ()
 	gint i, rows;
 	gboolean ok;
 	gchar *key,*buf[] = {" "};
+	gboolean has_default = FALSE;
 
 	/* get number of rows */
 	rows = (GTK_CLIST (clist)->rows);
@@ -323,10 +326,13 @@ satpref_qth_apply ()
 		g_free (key);
 
 		/* Is this the default location */
-		key = g_strconcat (QTH_ROOT_PATH, "/default", NULL);
 		if (gtk_clist_get_text (GTK_CLIST (clist), i, 9, buf)) {
-			if (!g_strcasecmp (buf[0], "YES"))
+			if (!g_strcasecmp (buf[0], "YES")) {
+				key = g_strconcat (QTH_ROOT_PATH, "/default", NULL);
 				ok = ok && gconf_client_set_int (client, key, i, NULL);
+				g_free (key);
+				has_default = TRUE;
+			}
 		}	
 		if (!ok) {
 			key = g_strdup_printf ("%s: Error saving location %d", __FUNCTION__, i);
@@ -335,6 +341,13 @@ satpref_qth_apply ()
 		}
 	}
 
+	/* set default QTH to 0 if not already set */
+	if (!has_default) {
+		key = g_strdup_printf ("%s/default", QTH_ROOT_PATH);
+		gconf_client_set_int (client, key, 0, NULL);
+		g_free (key);
+	}
+
 	/* Delete the rest from the Gconf config */
 	for (i=rows; satpref_qth_exists (i); i++) {
 		/* name */
@@ -428,17 +441,18 @@ satpref_qth_row_clicked_cb (GtkCList *clist,
 	/* This function is called when a row is selected
 	   or unselected. It check whether the CList has a
 	   valid selection and enables the buttons if so.
+	   NOTE: The delete button is enabled only if there
+	   are more than one QTH in the list.
 	*/
 	GList *selection = clist->selection;
-	gchar *buff[] = { " " };
 
 	if (selection) {
-		/* Default radio should not be deleted */
-		if (gtk_clist_get_text (clist, row, 9, buff)) {
-			if (g_strcasecmp (buff[0], "YES"))
-				gtk_widget_set_sensitive (delb, TRUE);
-			else
-				gtk_widget_set_sensitive (delb, FALSE);
+		/* If only one qth is in list don't enable Delete button */
+		if (clist->rows > 1) {
+			gtk_widget_set_sensitive (delb, TRUE);
+		}
+		else {
+			gtk_widget_set_sensitive (delb, FALSE);
 		}
 		gtk_widget_set_sensitive (editb, TRUE);
 		gtk_widget_set_sensitive (defb, TRUE);
@@ -600,7 +614,7 @@ satpref_qth_add_cb         (GtkWidget *button, gpointer clist)
 				"near your location."));
 	gtk_table_attach_defaults (GTK_TABLE (table), wxbut, 3, 4, 9, 10);
 
-#if defined (HAVE_LIBHAMLIB) && defined (HAVE_HAMLIB_ROTATOR_H)
+#if defined (HAVE_HAMLIB)
 	/* QRA locator */
 	label = gtk_label_new (_("Locator:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
@@ -881,7 +895,7 @@ satpref_qth_edit_cb        (GtkWidget *button, gpointer clist)
 					"near your location."));
 		gtk_table_attach_defaults (GTK_TABLE (table), wxbut, 3, 4, 9, 10);
 
-#if defined (HAVE_LIBHAMLIB) && defined (HAVE_HAMLIB_ROTATOR_H)
+#if defined (HAVE_HAMLIB)
 		/* QRA locator */
 		label = gtk_label_new (_("Locator:"));
 		gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
@@ -991,8 +1005,11 @@ satpref_qth_default_cb     (GtkWidget *button, gpointer clist)
 		for (i=0; i < (GTK_CLIST (clist)->rows); i++)
 			gtk_clist_set_text (GTK_CLIST (clist), i, 9,
 					    (i == row) ? "YES" : " ");
-		/* Disable "Delete" button, so we can't delete default location */
-		gtk_widget_set_sensitive (delb, FALSE);
+		/* Disable "Delete" button, so we can't delete default location
+		   N/A anymore: We allow deleting of default but only if more than
+		   one QTH is available.
+		*/
+/*		gtk_widget_set_sensitive (delb, FALSE);*/
 		/* trigger signal */
 		satpref_changed ();
 	}
@@ -1190,8 +1207,8 @@ satpref_qth_wxbut_cb (GtkWidget *button, gpointer data)
 
 
 
-/** THe rest is only included if hamlib 1.1.3 or later is used **/
-#if defined (HAVE_LIBHAMLIB) && defined (HAVE_HAMLIB_ROTATOR_H)
+/* THe rest is only included if hamlib 1.2.0 or later is used **/
+#if defined (HAVE_HAMLIB)
 
 static void
 satpref_qth_latlon_cb              (GtkAdjustment *adj, gpointer data)
@@ -1199,15 +1216,28 @@ satpref_qth_latlon_cb              (GtkAdjustment *adj, gpointer data)
 	/* This function is called when either the latitude or the longitude spin
 	   button is changed. It updates the locator entry.
 	*/
-	gchar *locator;
+	gchar locator[2*QRA_PAIR_COUNT+1];
 
+	/* Check whether user is typing into lat/lon entries or the change comes from
+	   automatic conversion (this can be checked by reading the status of the
+	   longitude-latitude radio button).
+	*/
 	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (radio1))) {
-		locator = g_malloc (7);
-		longlat2locator (gtk_spin_button_get_value_as_float (GTK_SPIN_BUTTON (lonsp)),
-				 gtk_spin_button_get_value_as_float (GTK_SPIN_BUTTON (latsp)),
-				 locator);
-		gtk_entry_set_text (GTK_ENTRY (qra_loc), locator);
-		g_free (locator);
+
+		/* Try to convert input */
+		if (longlat2locator (-gtk_spin_button_get_value_as_float (GTK_SPIN_BUTTON (lonsp)),
+				     gtk_spin_button_get_value_as_float (GTK_SPIN_BUTTON (latsp)),
+				     locator, QRA_PAIR_COUNT) == RIG_OK) {
+
+			/* Conversion is OK, update locator field */
+			gtk_entry_set_text (GTK_ENTRY (qra_loc), g_strdup (locator));
+		}
+		else {
+			/* Clear locator field and disable "Next" button
+			   because user is typing some junk.
+			   This could be avoided by using spinbuttons! */
+			gtk_entry_set_text (GTK_ENTRY (qra_loc), "");
+		}
 	}
 }
 
@@ -1249,7 +1279,7 @@ satpref_qth_qra_changed_cb    (GtkWidget *qra, gpointer data)
 
 		if (!locator2longlat (&lon, &lat, gtk_entry_get_text (GTK_ENTRY (qra)))) {
 			gtk_spin_button_set_value (GTK_SPIN_BUTTON (latsp), lat);
-			gtk_spin_button_set_value (GTK_SPIN_BUTTON (lonsp), lon);
+			gtk_spin_button_set_value (GTK_SPIN_BUTTON (lonsp), -lon);
 		}
 	}
 }
