@@ -3,7 +3,7 @@
 
   satpref-satlist.c: List preferences (widgets and funcs).
 
-  Copyright (C)  2001-2003  Alexandru Csete.
+  Copyright (C)  2001-2005  Alexandru Csete.
 
   Authors:  Alexandru Csete <csete@users.sourceforge.net>
 
@@ -55,8 +55,8 @@ enum default_buttons {
 
 
 GtkWidget *hcp,*ncp,*ghcp,*gncp,*dcp,*nocp;        /* color pickers */
-GtkObject *listadj;
-GtkWidget *listspin;
+GtkObject *listadj,*sortadj;
+GtkWidget *listspin,*sortspin;
 
 GdkColor norm,high,geoh,geon,dec,noaos;  /* satlist.c */
 
@@ -64,7 +64,7 @@ GdkColor norm,high,geoh,geon,dec,noaos;  /* satlist.c */
 extern GConfClient *client; /* main.c */
 
 /* private function prototypes */
-static void def_butt_cb (GtkWidget *,gpointer);
+static void def_butt_cb (GtkWidget *, gpointer);
 
 
 GtkWidget *satpref_satlist (void)
@@ -79,7 +79,7 @@ GtkWidget *satpref_satlist (void)
 	gint delay;
 
 	/* create table */
-	table = gtk_table_new (4, 7, FALSE);
+	table = gtk_table_new (4, 8, FALSE);
 	gtk_table_set_col_spacings (GTK_TABLE (table), 2);
 	gtk_table_set_row_spacings (GTK_TABLE (table), 2);
 
@@ -96,109 +96,124 @@ GtkWidget *satpref_satlist (void)
 			    GTK_SIGNAL_FUNC (satpref_changed), NULL);
 	gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (listspin), TRUE);
 	gtk_table_attach_defaults (GTK_TABLE (table), listspin, 2, 3, 0, 1);
-	label = gtk_label_new (_(" [msec]") );
+	label = gtk_label_new (_(" [msec]"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0f, 0.5f);
 	gtk_table_attach_defaults (GTK_TABLE (table), label, 3, 4, 0, 1);
+
+	/* autoupdate interval */
+	label = gtk_label_new (_("Auto-sort interval (0=disabled)"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0f, 0.5f);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 1, 2);
+	sortadj = gtk_adjustment_new (gconf_client_get_int (client, SATLIST_AUTOSORT_PATH, NULL),
+				      0, 100, 1, 10, 0);
+	sortspin = gtk_spin_button_new (GTK_ADJUSTMENT (sortadj), 0.5, 0);
+	gtk_signal_connect (GTK_OBJECT (sortspin), "changed",
+			    GTK_SIGNAL_FUNC (satpref_changed), NULL);
+	gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (sortspin), TRUE);
+	gtk_table_attach_defaults (GTK_TABLE (table), sortspin, 2, 3, 1, 2);
+	label = gtk_label_new (_(" [sec]"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0f, 0.5f);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 3, 4, 1, 2);
+
 	/***************************************/
 	/* color picker for sats above horizon */
 	/***************************************/
-
 	/** FIRST READ IN THE COLORS!         **/
 	/* color for satellites above horizon */
-        if ( (rgb = gconf_client_get_string (client, SATLIST_HRGB_PATH, NULL)) ) {
+        if ((rgb = gconf_client_get_string (client, SATLIST_HRGB_PATH, NULL))) {
 		rgbv = g_strsplit ( rgb, ",", 3);
-		high.red = (gushort) g_strtod (rgbv[0], NULL);
-		high.green = (gushort)g_strtod (rgbv[1], NULL);
-		high.blue = (gushort)g_strtod (rgbv[2], NULL);
+		high.red   = (gushort) g_strtod (rgbv[0], NULL);
+		high.green = (gushort) g_strtod (rgbv[1], NULL);
+		high.blue  = (gushort) g_strtod (rgbv[2], NULL);
 		g_free (rgb);
 		g_strfreev (rgbv);
 	} else {
-		high.red = SATLIST_DEF_HIGH_RED;
+		high.red   = SATLIST_DEF_HIGH_RED;
 		high.green = SATLIST_DEF_HIGH_GREEN;
-		high.blue = SATLIST_DEF_HIGH_BLUE;
+		high.blue  = SATLIST_DEF_HIGH_BLUE;
 	}
 	/* color for satellites below horizon */
-	if ( (rgb = gconf_client_get_string (client, SATLIST_NRGB_PATH, NULL)) ) {
+	if ((rgb = gconf_client_get_string (client, SATLIST_NRGB_PATH, NULL))) {
 		rgbv = g_strsplit (rgb, ",", 3);
-		norm.red = (gushort) g_strtod (rgbv[0], NULL);
+		norm.red   = (gushort) g_strtod (rgbv[0], NULL);
 		norm.green = (gushort) g_strtod (rgbv[1], NULL);
-		norm.blue = (gushort) g_strtod (rgbv[2], NULL);
+		norm.blue  = (gushort) g_strtod (rgbv[2], NULL);
 		g_free (rgb);
 		g_strfreev (rgbv);
 	} else {
-		norm.red = SATLIST_DEF_NORM_RED;
+		norm.red   = SATLIST_DEF_NORM_RED;
 		norm.green = SATLIST_DEF_NORM_GREEN;
-		norm.blue = SATLIST_DEF_NORM_BLUE;
+		norm.blue  = SATLIST_DEF_NORM_BLUE;
 	}
 	/* Get geostationary below hor color */
-	if ( (rgb = gconf_client_get_string (client, SATLIST_GNRGB_PATH, NULL)) ) {
+	if ((rgb = gconf_client_get_string (client, SATLIST_GNRGB_PATH, NULL))) {
 		rgbv = g_strsplit (rgb, ",", 3);
-		geon.red = (gushort) g_strtod (rgbv[0], NULL);
-		geon.green = (gushort) g_strtod(rgbv[1], NULL);
-		geon.blue = (gushort) g_strtod (rgbv[2], NULL);
+		geon.red   = (gushort) g_strtod (rgbv[0], NULL);
+		geon.green = (gushort) g_strtod (rgbv[1], NULL);
+		geon.blue  = (gushort) g_strtod (rgbv[2], NULL);
 		g_free (rgb);
 		g_strfreev (rgbv);
 	} else {
-		geon.red = SATLIST_DEF_NORM_RED;
+		geon.red   = SATLIST_DEF_NORM_RED;
 		geon.green = SATLIST_DEF_NORM_GREEN;
-		geon.blue = SATLIST_DEF_NORM_BLUE;
+		geon.blue  = SATLIST_DEF_NORM_BLUE;
 	}
 	/* Get geostationary above hor color */
-	if ( (rgb = gconf_client_get_string (client, SATLIST_GHRGB_PATH, NULL)) ) {
+	if ((rgb = gconf_client_get_string (client, SATLIST_GHRGB_PATH, NULL))) {
 		rgbv = g_strsplit (rgb, ",", 3);
-		geoh.red = (gushort) g_strtod (rgbv[0], NULL);
+		geoh.red   = (gushort) g_strtod (rgbv[0], NULL);
 		geoh.green = (gushort) g_strtod (rgbv[1], NULL);
-		geoh.blue = (gushort) g_strtod (rgbv[2], NULL);
+		geoh.blue  = (gushort) g_strtod (rgbv[2], NULL);
 		g_free (rgb);
 		g_strfreev (rgbv);
 	} else {
-		geoh.red = SATLIST_DEF_HIGH_RED;
+		geoh.red   = SATLIST_DEF_HIGH_RED;
 		geoh.green = SATLIST_DEF_HIGH_GREEN;
-		geoh.blue = SATLIST_DEF_HIGH_BLUE;
+		geoh.blue  = SATLIST_DEF_HIGH_BLUE;
 	}
 	/* Get decayed color */
-	if ( (rgb = gconf_client_get_string (client, SATLIST_DRGB_PATH, NULL)) ) {
+	if ((rgb = gconf_client_get_string (client, SATLIST_DRGB_PATH, NULL))) {
 		rgbv = g_strsplit (rgb, ",", 3);
-		dec.red = (gushort) g_strtod (rgbv[0], NULL);
+		dec.red   = (gushort) g_strtod (rgbv[0], NULL);
 		dec.green = (gushort) g_strtod (rgbv[1], NULL);
-		dec.blue = (gushort) g_strtod (rgbv[2], NULL);
+		dec.blue  = (gushort) g_strtod (rgbv[2], NULL);
 		g_free (rgb);
 		g_strfreev (rgbv);
 	} else {
-		dec.red = SATLIST_DEF_NORM_RED;
+		dec.red   = SATLIST_DEF_NORM_RED;
 		dec.green = SATLIST_DEF_NORM_GREEN;
-		dec.blue = SATLIST_DEF_NORM_BLUE;
+		dec.blue  = SATLIST_DEF_NORM_BLUE;
 	}
 	/* Get no AOS color */
-	if ( (rgb = gconf_client_get_string (client, SATLIST_NARGB_PATH, NULL)) ) {
+	if ((rgb = gconf_client_get_string (client, SATLIST_NARGB_PATH, NULL))) {
 		rgbv = g_strsplit (rgb, ",", 3);
-		noaos.red = (gushort) g_strtod (rgbv[0], NULL);
+		noaos.red   = (gushort) g_strtod (rgbv[0], NULL);
 		noaos.green = (gushort) g_strtod (rgbv[1], NULL);
-		noaos.blue = (gushort) g_strtod (rgbv[2], NULL);
+		noaos.blue  = (gushort) g_strtod (rgbv[2], NULL);
 		g_free (rgb);
 		g_strfreev (rgbv);
 	} else {
-		noaos.red = SATLIST_DEF_NORM_RED;
+		noaos.red   = SATLIST_DEF_NORM_RED;
 		noaos.green = SATLIST_DEF_NORM_GREEN;
-		noaos.blue = SATLIST_DEF_NORM_BLUE;
+		noaos.blue  = SATLIST_DEF_NORM_BLUE;
 	}
 
 
 	label = gtk_label_new (_("Satellites above horizon"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0f, 0.5f);
-	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 1, 2);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 2, 3);
 	/* color picker */
 	hcp = gnome_color_picker_new ();
 	gtk_signal_connect (GTK_OBJECT (hcp), "color-set",
 			    GTK_SIGNAL_FUNC (satpref_changed), NULL);
 	gnome_color_picker_set_i16 (GNOME_COLOR_PICKER (hcp),
 				    high.red, high.green, high.blue, 0);
-	gtk_table_attach_defaults (GTK_TABLE (table), hcp, 2, 3, 1, 2);
+	gtk_table_attach_defaults (GTK_TABLE (table), hcp, 2, 3, 2, 3);
 	/* "reset to default" button */
 	hcb = gtk_button_new_with_label (_("Default"));
 	gtk_signal_connect (GTK_OBJECT (hcb), "clicked",
 			    GTK_SIGNAL_FUNC (def_butt_cb), GUINT_TO_POINTER (DEF_BUT_AHOR));
-	gtk_table_attach_defaults (GTK_TABLE (table), hcb, 3, 4, 1, 2);
+	gtk_table_attach_defaults (GTK_TABLE (table), hcb, 3, 4, 2, 3);
 	/* add some tooltips */
 	kooltip = gtk_tooltips_new ();
 	gtk_tooltips_set_tip (GTK_TOOLTIPS (kooltip), GTK_WIDGET (hcp),
@@ -211,126 +226,130 @@ GtkWidget *satpref_satlist (void)
 	/***************************************/
 	label = gtk_label_new (_("Satellites below horizon"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0f, 0.5f);
-	gtk_table_attach_defaults (GTK_TABLE(table), label, 1, 2, 2, 3);
+	gtk_table_attach_defaults (GTK_TABLE(table), label, 1, 2, 3, 4);
 	/* color picker */
 	ncp = gnome_color_picker_new ();
 	gtk_signal_connect (GTK_OBJECT (ncp), "color-set",
 			    GTK_SIGNAL_FUNC (satpref_changed), NULL);
 	gnome_color_picker_set_i16 (GNOME_COLOR_PICKER (ncp),
 				    norm.red, norm.green, norm.blue, 0);
-	gtk_table_attach_defaults (GTK_TABLE (table), ncp, 2, 3, 2, 3);
+	gtk_table_attach_defaults (GTK_TABLE (table), ncp, 2, 3, 3, 4);
 	/* "reset to default" button */
 	ncb = gtk_button_new_with_label(_("Default"));
 	gtk_signal_connect (GTK_OBJECT (ncb), "clicked",
 			    GTK_SIGNAL_FUNC (def_butt_cb), GUINT_TO_POINTER (DEF_BUT_BHOR));
-	gtk_table_attach_defaults (GTK_TABLE (table), ncb, 3, 4, 2, 3);
+	gtk_table_attach_defaults (GTK_TABLE (table), ncb, 3, 4, 3, 4);
 	/* add some tooltips */
 	kooltip = gtk_tooltips_new ();
 	gtk_tooltips_set_tip (GTK_TOOLTIPS (kooltip), GTK_WIDGET (ncp),
 			      _("Click to change the color"), NULL);
 	kooltip = gtk_tooltips_new ();
-	gtk_tooltips_set_tip (GTK_TOOLTIPS(kooltip), GTK_WIDGET (ncb),
+	gtk_tooltips_set_tip (GTK_TOOLTIPS (kooltip), GTK_WIDGET (ncb),
 			      _("Reset to the default color"), NULL);
 	/*****************************************************/
 	/* color picker for geostationary sats above horizon */
 	/*****************************************************/
 	label = gtk_label_new(_("Geostationary above horizon"));
-	gtk_misc_set_alignment( GTK_MISC(label), 0.0f, 0.5f );
-	gtk_table_attach_defaults( GTK_TABLE(table), label, 1, 2, 3, 4 );
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0f, 0.5f);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 4, 5);
 	/* color picker */
-	ghcp = gnome_color_picker_new();
-	gtk_signal_connect( GTK_OBJECT(ghcp), "color-set",
-			    GTK_SIGNAL_FUNC(satpref_changed), NULL );
-	gnome_color_picker_set_i16( GNOME_COLOR_PICKER(ghcp),
-				    geoh.red, geoh.green, geoh.blue, 0 );
-	gtk_table_attach_defaults( GTK_TABLE(table), ghcp, 2, 3, 3, 4 );
+	ghcp = gnome_color_picker_new ();
+	gtk_signal_connect (GTK_OBJECT (ghcp), "color-set",
+			    GTK_SIGNAL_FUNC (satpref_changed), NULL);
+	gnome_color_picker_set_i16 (GNOME_COLOR_PICKER (ghcp),
+				    geoh.red, geoh.green, geoh.blue, 0);
+	gtk_table_attach_defaults (GTK_TABLE (table), ghcp, 2, 3, 4, 5);
 	/* "reset to default" button */
-	ghcb = gtk_button_new_with_label(_("Default"));
-	gtk_signal_connect( GTK_OBJECT(ghcb), "clicked",
-			    GTK_SIGNAL_FUNC(def_butt_cb), GUINT_TO_POINTER( DEF_BUT_GEO_A ) );
-	gtk_table_attach_defaults( GTK_TABLE(table), ghcb, 3, 4, 3, 4 );
+	ghcb = gtk_button_new_with_label (_("Default"));
+	gtk_signal_connect (GTK_OBJECT (ghcb), "clicked",
+			    GTK_SIGNAL_FUNC (def_butt_cb), 
+			    GUINT_TO_POINTER (DEF_BUT_GEO_A));
+	gtk_table_attach_defaults (GTK_TABLE (table), ghcb, 3, 4, 4, 5);
 	/* add some tooltips */
-	kooltip = gtk_tooltips_new();
-	gtk_tooltips_set_tip( GTK_TOOLTIPS(kooltip), GTK_WIDGET(ghcp),
-			      _("Click to change the color"), NULL );
-	kooltip = gtk_tooltips_new();
-	gtk_tooltips_set_tip( GTK_TOOLTIPS(kooltip), GTK_WIDGET(ghcb),
-			      _("Reset to the default color"), NULL );
+	kooltip = gtk_tooltips_new ();
+	gtk_tooltips_set_tip (GTK_TOOLTIPS (kooltip), GTK_WIDGET (ghcp),
+			      _("Click to change the color"), NULL);
+	kooltip = gtk_tooltips_new ();
+	gtk_tooltips_set_tip (GTK_TOOLTIPS (kooltip), GTK_WIDGET (ghcb),
+			      _("Reset to the default color"), NULL);
 	/*****************************************************/
 	/* color picker for geostationary sats below horizon */
 	/*****************************************************/
-	label = gtk_label_new(_("Geostationary below horizon"));
-	gtk_misc_set_alignment( GTK_MISC(label), 0.0f, 0.5f );
-	gtk_table_attach_defaults( GTK_TABLE(table), label, 1, 2, 4, 5 );
+	label = gtk_label_new (_("Geostationary below horizon"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0f, 0.5f);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 5, 6);
 	/* color picker */
-	gncp = gnome_color_picker_new();
-	gtk_signal_connect( GTK_OBJECT(gncp), "color-set",
-			    GTK_SIGNAL_FUNC(satpref_changed), NULL );
-	gnome_color_picker_set_i16( GNOME_COLOR_PICKER(gncp),
-				    geon.red, geon.green, geon.blue, 0 );
-	gtk_table_attach_defaults( GTK_TABLE(table), gncp, 2, 3, 4, 5 );
+	gncp = gnome_color_picker_new ();
+	gtk_signal_connect (GTK_OBJECT (gncp), "color-set",
+			    GTK_SIGNAL_FUNC (satpref_changed), NULL);
+	gnome_color_picker_set_i16 (GNOME_COLOR_PICKER (gncp),
+				    geon.red, geon.green, geon.blue, 0);
+	gtk_table_attach_defaults (GTK_TABLE (table), gncp, 2, 3, 5, 6);
 	/* "reset to default" button */
-	gncb = gtk_button_new_with_label(_("Default"));
-	gtk_signal_connect( GTK_OBJECT(gncb), "clicked",
-			    GTK_SIGNAL_FUNC(def_butt_cb), GUINT_TO_POINTER( DEF_BUT_GEO_B ) );
-	gtk_table_attach_defaults( GTK_TABLE(table), gncb, 3, 4, 4, 5 );
+	gncb = gtk_button_new_with_label (_("Default"));
+	gtk_signal_connect (GTK_OBJECT (gncb), "clicked",
+			    GTK_SIGNAL_FUNC (def_butt_cb),
+			    GUINT_TO_POINTER (DEF_BUT_GEO_B));
+	gtk_table_attach_defaults (GTK_TABLE (table), gncb, 3, 4, 5, 6);
 	/* add some tooltips */
-	kooltip = gtk_tooltips_new();
-	gtk_tooltips_set_tip( GTK_TOOLTIPS(kooltip), GTK_WIDGET(gncp),
-			      _("Click to change the color"), NULL );
-	kooltip = gtk_tooltips_new();
-	gtk_tooltips_set_tip( GTK_TOOLTIPS(kooltip), GTK_WIDGET(gncb),
-			      _("Reset to the default color"), NULL );
+	kooltip = gtk_tooltips_new ();
+	gtk_tooltips_set_tip (GTK_TOOLTIPS (kooltip), GTK_WIDGET (gncp),
+			      _("Click to change the color"), NULL);
+	kooltip = gtk_tooltips_new ();
+	gtk_tooltips_set_tip (GTK_TOOLTIPS (kooltip), GTK_WIDGET (gncb),
+			      _("Reset to the default color"), NULL);
 	/*************************************/
 	/* color picker for sats with NO AOS */
 	/*************************************/
-	label = gtk_label_new(_("Satellites with no AOS"));
-	gtk_misc_set_alignment( GTK_MISC(label), 0.0f, 0.5f );
-	gtk_table_attach_defaults( GTK_TABLE(table), label, 1, 2, 5, 6 );
+	label = gtk_label_new (_("Satellites with no AOS"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0f, 0.5f);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 6, 7);
 	/* color picker */
-	nocp = gnome_color_picker_new();
-	gtk_signal_connect( GTK_OBJECT(nocp), "color-set",
-			    GTK_SIGNAL_FUNC(satpref_changed), NULL );
-	gnome_color_picker_set_i16( GNOME_COLOR_PICKER(nocp),
-				    noaos.red, noaos.green, noaos.blue, 0 );
-	gtk_table_attach_defaults( GTK_TABLE(table), nocp, 2, 3, 5, 6 );
+	nocp = gnome_color_picker_new ();
+	gtk_signal_connect (GTK_OBJECT (nocp), "color-set",
+			    GTK_SIGNAL_FUNC (satpref_changed), NULL);
+	gnome_color_picker_set_i16 (GNOME_COLOR_PICKER (nocp),
+				    noaos.red, noaos.green, noaos.blue, 0);
+	gtk_table_attach_defaults (GTK_TABLE (table), nocp, 2, 3, 6, 7);
 	/* "reset to default" button */
-	nocb = gtk_button_new_with_label(_("Default"));
-	gtk_signal_connect( GTK_OBJECT(nocb), "clicked",
-			    GTK_SIGNAL_FUNC(def_butt_cb), GUINT_TO_POINTER( DEF_BUT_NOAOS ) );
-	gtk_table_attach_defaults( GTK_TABLE(table), nocb, 3, 4, 5, 6 );
+	nocb = gtk_button_new_with_label (_("Default"));
+	gtk_signal_connect (GTK_OBJECT (nocb), "clicked",
+			    GTK_SIGNAL_FUNC (def_butt_cb),
+			    GUINT_TO_POINTER (DEF_BUT_NOAOS));
+	gtk_table_attach_defaults (GTK_TABLE (table), nocb, 3, 4, 6, 7);
 	/* add some tooltips */
-	kooltip = gtk_tooltips_new();
-	gtk_tooltips_set_tip( GTK_TOOLTIPS(kooltip), GTK_WIDGET(nocp),
-			      _("Click to change the color"), NULL );
-	kooltip = gtk_tooltips_new();
-	gtk_tooltips_set_tip( GTK_TOOLTIPS(kooltip), GTK_WIDGET(nocb),
-			      _("Reset to the default color"), NULL );
+	kooltip = gtk_tooltips_new ();
+	gtk_tooltips_set_tip (GTK_TOOLTIPS (kooltip), GTK_WIDGET (nocp),
+			      _("Click to change the color"), NULL);
+	kooltip = gtk_tooltips_new ();
+	gtk_tooltips_set_tip (GTK_TOOLTIPS (kooltip), GTK_WIDGET (nocb),
+			      _("Reset to the default color"), NULL);
 	/*********************************/
 	/* color picker for decayed sats */
 	/*********************************/
-	label = gtk_label_new(_("Satellites that have decayed"));
-	gtk_misc_set_alignment( GTK_MISC(label), 0.0f, 0.5f );
-	gtk_table_attach_defaults( GTK_TABLE(table), label, 1, 2, 6, 7 );
+	label = gtk_label_new (_("Satellites that have decayed"));
+	gtk_misc_set_alignment (GTK_MISC(label), 0.0f, 0.5f);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 7, 8);
 	/* color picker */
-	dcp = gnome_color_picker_new();
-	gtk_signal_connect( GTK_OBJECT(dcp), "color-set",
-			    GTK_SIGNAL_FUNC(satpref_changed), NULL );
-	gnome_color_picker_set_i16( GNOME_COLOR_PICKER(dcp),
-				    dec.red, dec.green, dec.blue, 0 );
-	gtk_table_attach_defaults( GTK_TABLE(table), dcp, 2, 3, 6, 7 );
+	dcp = gnome_color_picker_new ();
+	gtk_signal_connect (GTK_OBJECT (dcp), "color-set",
+			    GTK_SIGNAL_FUNC (satpref_changed), NULL);
+	gnome_color_picker_set_i16 (GNOME_COLOR_PICKER (dcp),
+				    dec.red, dec.green, dec.blue, 0);
+	gtk_table_attach_defaults (GTK_TABLE (table), dcp, 2, 3, 7, 8);
 	/* "reset to default" button */
-	dcb = gtk_button_new_with_label(_("Default"));
-	gtk_signal_connect( GTK_OBJECT(dcb), "clicked",
-			    GTK_SIGNAL_FUNC(def_butt_cb), GUINT_TO_POINTER( DEF_BUT_DEC ) );
-	gtk_table_attach_defaults( GTK_TABLE(table), dcb, 3, 4, 6, 7 );
+	dcb = gtk_button_new_with_label (_("Default"));
+	gtk_signal_connect (GTK_OBJECT (dcb), "clicked",
+			    GTK_SIGNAL_FUNC (def_butt_cb), 
+			    GUINT_TO_POINTER (DEF_BUT_DEC));
+	gtk_table_attach_defaults (GTK_TABLE (table), dcb, 3, 4, 7, 8);
 	/* add some tooltips */
-	kooltip = gtk_tooltips_new();
-	gtk_tooltips_set_tip( GTK_TOOLTIPS(kooltip), GTK_WIDGET(dcp),
-			      _("Click to change the color"), NULL );
-	kooltip = gtk_tooltips_new();
-	gtk_tooltips_set_tip( GTK_TOOLTIPS(kooltip), GTK_WIDGET(dcb),
-			      _("Reset to the default color"), NULL );
+	kooltip = gtk_tooltips_new ();
+	gtk_tooltips_set_tip (GTK_TOOLTIPS (kooltip), GTK_WIDGET (dcp),
+			      _("Click to change the color"), NULL);
+	kooltip = gtk_tooltips_new ();
+	gtk_tooltips_set_tip (GTK_TOOLTIPS (kooltip), GTK_WIDGET (dcb),
+			      _("Reset to the default color"), NULL);
 
 	return table;
 }
@@ -345,37 +364,37 @@ void satpref_satlist_apply (void)
 	/* sats below horizon */
 	gnome_color_picker_get_i16 (GNOME_COLOR_PICKER (ncp),
 				    &r, &g, &b, &a );
-	buff = g_strdup_printf ("%d,%d,%d",r,g,b);
+	buff = g_strdup_printf ("%d,%d,%d", r, g, b);
 	gconf_client_set_string (client, SATLIST_NRGB_PATH, buff, NULL);
 	g_free (buff);
 	/* sats above horizon */
 	gnome_color_picker_get_i16 (GNOME_COLOR_PICKER (hcp),
 				    &r, &g, &b, &a );
-	buff = g_strdup_printf ("%d,%d,%d",r,g,b);
+	buff = g_strdup_printf ("%d,%d,%d", r, g, b);
 	gconf_client_set_string (client, SATLIST_HRGB_PATH, buff, NULL);
 	g_free (buff);
 	/* geostationary sats below horizon */
 	gnome_color_picker_get_i16 (GNOME_COLOR_PICKER (gncp),
 				    &r, &g, &b, &a );
-	buff = g_strdup_printf ("%d,%d,%d",r,g,b);
+	buff = g_strdup_printf ("%d,%d,%d", r, g, b);
 	gconf_client_set_string (client, SATLIST_GNRGB_PATH, buff, NULL);
 	g_free (buff);
 	/* geostationary sats above horizon */
 	gnome_color_picker_get_i16 (GNOME_COLOR_PICKER (ghcp),
 				    &r, &g, &b, &a );
-	buff = g_strdup_printf ("%d,%d,%d",r,g,b);
+	buff = g_strdup_printf ("%d,%d,%d", r, g, b);
 	gconf_client_set_string (client, SATLIST_GHRGB_PATH, buff, NULL);
 	g_free (buff);
 	/* decayed sats */
 	gnome_color_picker_get_i16 (GNOME_COLOR_PICKER (dcp),
 				    &r, &g, &b, &a );
-	buff = g_strdup_printf ("%d,%d,%d",r,g,b);
+	buff = g_strdup_printf ("%d,%d,%d", r, g, b);
 	gconf_client_set_string (client, SATLIST_DRGB_PATH, buff, NULL);
 	g_free (buff);
 	/* sats with no AOS */
 	gnome_color_picker_get_i16 (GNOME_COLOR_PICKER (nocp),
 				    &r, &g, &b, &a );
-	buff = g_strdup_printf ("%d,%d,%d",r,g,b);
+	buff = g_strdup_printf ("%d,%d,%d", r, g, b);
 	gconf_client_set_string (client, SATLIST_NARGB_PATH, buff, NULL);
 	g_free (buff);
 
@@ -384,6 +403,11 @@ void satpref_satlist_apply (void)
 			      gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (listspin)),
 			      NULL);
 
+	/* autosort timer */
+	gconf_client_set_int (client, SATLIST_AUTOSORT_PATH,
+			      gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (sortspin)),
+			      NULL);
+
 }
 
 
@@ -395,42 +419,42 @@ def_butt_cb (GtkWidget *but, gpointer data)
 		high.red   = SATLIST_DEF_HIGH_RED;
 		high.green = SATLIST_DEF_HIGH_GREEN;
 		high.blue  = SATLIST_DEF_HIGH_BLUE;
-		gnome_color_picker_set_i16( GNOME_COLOR_PICKER(hcp),
+		gnome_color_picker_set_i16 (GNOME_COLOR_PICKER (hcp),
 					    high.red, high.green, high.blue, 0 );
 		break;
 	case DEF_BUT_BHOR:
 		norm.red   = SATLIST_DEF_NORM_RED;
 		norm.green = SATLIST_DEF_NORM_GREEN;
 		norm.blue  = SATLIST_DEF_NORM_BLUE;
-		gnome_color_picker_set_i16( GNOME_COLOR_PICKER(ncp),
+		gnome_color_picker_set_i16 (GNOME_COLOR_PICKER (ncp),
 					    norm.red, norm.green, norm.blue, 0 );
 		break;
 	case DEF_BUT_GEO_A:
 		geoh.red   = SATLIST_DEF_HIGH_RED;
 		geoh.green = SATLIST_DEF_HIGH_GREEN;
 		geoh.blue  = SATLIST_DEF_HIGH_BLUE;
-		gnome_color_picker_set_i16( GNOME_COLOR_PICKER(ghcp),
+		gnome_color_picker_set_i16 (GNOME_COLOR_PICKER (ghcp),
 					    geoh.red, geoh.green, geoh.blue, 0 );
 		break;
 	case DEF_BUT_GEO_B:
 		geon.red   = SATLIST_DEF_NORM_RED;
 		geon.green = SATLIST_DEF_NORM_GREEN;
 		geon.blue  = SATLIST_DEF_NORM_BLUE;
-		gnome_color_picker_set_i16( GNOME_COLOR_PICKER(gncp),
+		gnome_color_picker_set_i16 (GNOME_COLOR_PICKER (gncp),
 					    geon.red, geon.green, geon.blue, 0 );
 		break;
 	case DEF_BUT_DEC:
 		dec.red   = SATLIST_DEF_NORM_RED;
 		dec.green = SATLIST_DEF_NORM_GREEN;
 		dec.blue  = SATLIST_DEF_NORM_BLUE;
-		gnome_color_picker_set_i16( GNOME_COLOR_PICKER(dcp),
+		gnome_color_picker_set_i16 (GNOME_COLOR_PICKER (dcp),
 					    dec.red, dec.green, dec.blue, 0 );
 		break;
 	case DEF_BUT_NOAOS:
 		noaos.red   = SATLIST_DEF_NORM_RED;
 		noaos.green = SATLIST_DEF_NORM_GREEN;
 		noaos.blue  = SATLIST_DEF_NORM_BLUE;
-		gnome_color_picker_set_i16( GNOME_COLOR_PICKER(nocp),
+		gnome_color_picker_set_i16 (GNOME_COLOR_PICKER (nocp),
 					    noaos.red, noaos.green, noaos.blue, 0 );
 		break;
 	default:
