@@ -2,7 +2,7 @@
 /*
   satprint.c: Printing functions.
 
-  Copyright (C)  2001-2003  Ran Hadary & Alexandru Csete.
+  Copyright (C)  2001-2005  Ran Hadary & Alexandru Csete.
 
   Authors:   Rand Hadary <hadary@users.sourceforge.net>
              Alexandru Csete <csete@users.sourceforge.net>
@@ -58,29 +58,28 @@ gint pos_y, gHighlight;
 
 extern qth_struc qth; /* qth.c */
 
-/* Private Functions prototype                                     */
-static void satp_calc_paper_size (gchar *);
-static void satp_highlight_line (GnomePrintContext *, gint, gint, gint);
-static void satp_page_header (GnomePrintContext *);
-static void satp_page_footer (GnomePrintContext *, guint, guint);
-static void satp_print_qth (GnomePrintContext *);
-static void satp_sat_data_print (GnomePrintContext *, sat_t *);
-static gint satp_aosline_print (GnomePrintContext *, gchar *);
-static gint satp_sat_textline (GnomePrintContext *, gchar **);
-static gint satp_satline_print (GnomePrintContext *, guint);
-static void satp_satlist_header (GnomePrintContext *);
-static void satp_satlist_print (GnomePrintContext *);
-static void satp_aosdet_header (GnomePrintContext *);
+/* Private Functions prototype */
+static void satp_calc_paper_size  (gchar *);
+static void satp_highlight_line   (GnomePrintContext *, gint, gint, gint);
+static void satp_page_header      (GnomePrintContext *);
+static void satp_page_footer      (GnomePrintContext *, guint, guint);
+static void satp_print_qth        (GnomePrintContext *);
+static void satp_sat_data_print   (GnomePrintContext *, sat_t *);
+static gint satp_aosline_print    (GnomePrintContext *, gchar *);
+static gint satp_sat_textline     (GnomePrintContext *, gchar **);
+static gint satp_satline_print    (GnomePrintContext *, guint);
+static void satp_satlist_header   (GnomePrintContext *);
+static void satp_satlist_print    (GnomePrintContext *);
+static void satp_aosdet_header    (GnomePrintContext *, sat_t *, guint);
 static gint satp_aosdetline_print (GnomePrintContext * ,gchar *);
-/* End Private functions                                           */
 
 
-/* Calculate the paper size                                             */
+/* Calculate the paper size */
 static void satp_calc_paper_size (gchar *PaperSize) 
 {
 	const GnomePaper *gp;
 
-	/* Claculate the paper size                                       */
+	/* Claculate the paper size */
 	gp = gnome_paper_with_name (PaperSize);
 	paper_height = gnome_paper_psheight (gp);
 	paper_width = gnome_paper_pswidth (gp);
@@ -108,7 +107,8 @@ satp_highlight_line (GnomePrintContext *pc, gint pos_lh , gint pos_rh, gint heig
 }
 
 
-static void satp_page_header (GnomePrintContext *pc) 
+static void
+satp_page_header (GnomePrintContext *pc) 
 {
 
 	/* Standard page header for Gnome-Predict                        */
@@ -121,14 +121,15 @@ static void satp_page_header (GnomePrintContext *pc)
 	gchar* path;
 	GdkPixbuf *pb = NULL;
 
-	/* Load application icon                                         */
-	path = g_strconcat (PACKAGE_PIXMAPS_DIR, "/icons/gpredict-icon.png", NULL);
+	/* Load application icon */
+	path = g_strconcat (PACKAGE_PIXMAPS_DIR, G_DIR_SEPARATOR_S, "icons",
+			    G_DIR_SEPARATOR_S, "gpredict-icon.png", NULL);
 	pb = gdk_pixbuf_new_from_file (path);
 	if (pb == NULL)
 		satlog_log (SAT_LOG_CRITICAL, _("SATPRINT: Could not load icon"));
 	else {
 		gnome_print_gsave (pc);
-		gnome_print_translate (pc, 40, (paper_height - 40));
+		gnome_print_translate (pc, 60, (paper_height - 60));
 		gnome_print_scale (pc, gdk_pixbuf_get_width(pb), gdk_pixbuf_get_height (pb));
 		gnome_print_moveto (pc, 0, 0);
 		gnome_print_pixbuf (pc, pb);
@@ -137,19 +138,19 @@ static void satp_page_header (GnomePrintContext *pc)
 	gdk_pixbuf_unref (pb);
 	g_free (path);
 
-	/* Set the font closest to Times New Roman                       */
+	/* Set the font closest to Times New Roman */
 	font = gnome_font_new_closest ("Times", GNOME_FONT_BOLD, 1, 24);
 	if (font == NULL ) {
 		satlog_log (SAT_LOG_CRITICAL, _("SATPRINT: Font TIMES not found"));
 		return; 
 	}
 
-	/* Print package name and version                                */
+	/* Print package name and version */
 	gnome_print_gsave (pc);
 	gnome_print_setfont (pc, font);
 	pos_y -= 30;
-	buf = g_strdup_printf (_("Gnome-Predict %s"), _(VERSION)); 
-	text_width = gnome_font_get_width_string (font,buf);
+	buf = g_strconcat (_("Gnome Predict"), "  ", VERSION, NULL); 
+	text_width = gnome_font_get_width_string (font, buf);
 	gnome_print_moveto (pc, ((paper_width - text_width)/2), pos_y);
 	gnome_print_show (pc, buf);
 	g_free (buf);
@@ -157,7 +158,8 @@ static void satp_page_header (GnomePrintContext *pc)
 }
 
 
-static void satp_page_footer (GnomePrintContext *pc, guint pg, guint pgs)
+static void
+satp_page_footer (GnomePrintContext *pc, guint pg, guint pgs)
 {
 	/* Print page footer                                 */
 	/* Print the "Page # of ##" at the buttom right side */
@@ -167,13 +169,12 @@ static void satp_page_footer (GnomePrintContext *pc, guint pg, guint pgs)
 	gnome_print_gsave (pc);
 	font = gnome_font_new_closest ("Times", GNOME_FONT_BOLD, 1, 10);
 	gnome_print_setfont (pc, font);
-	/**** FIXME: string not translated (bug #522419) */
 	buf = g_strdup_printf (_("Page %2.0i of %2.0i"), pg, pgs);
 
-	gnome_print_moveto (pc, 40, 25);
-	gnome_print_lineto (pc, 560, 25);
+	gnome_print_moveto (pc, 40, 40);
+	gnome_print_lineto (pc, paper_width - 95, 40);
 	gnome_print_stroke (pc);
-	gnome_print_moveto (pc, 450, 10);
+	gnome_print_moveto (pc, 450, 25);
 	gnome_print_show (pc, buf);
 	g_free (buf);
 	gtk_object_unref (GTK_OBJECT (font));
@@ -182,7 +183,8 @@ static void satp_page_footer (GnomePrintContext *pc, guint pg, guint pgs)
 }
 
 
-static void satp_print_qth (GnomePrintContext *pc)
+static void
+satp_print_qth (GnomePrintContext *pc)
 {
 	GnomeFont* font;
 	gchar* buf;
@@ -192,10 +194,9 @@ static void satp_print_qth (GnomePrintContext *pc)
 	gnome_print_setfont (pc, font);
 
 	/* First line - includes the name and the description        */
-	/**** FIXME: string not translated (bug #522419) */
 	buf = g_strdup_printf (_("Station: %s (%s)"), qth.name, qth.desc);
 	pos_y -= 22;
-	gnome_print_moveto (pc, 30, pos_y);
+	gnome_print_moveto (pc, 40, pos_y);
 	gnome_print_show (pc, buf);
 	g_free (buf);
 
@@ -205,29 +206,29 @@ static void satp_print_qth (GnomePrintContext *pc)
 			      qth.loc, fabs (qth.lat), (qth.lat < 0) ? 'S' : 'N',
 			      fabs (qth.lon), (qth.lon < 0) ? 'E' : 'W', qth.alt );
 	pos_y -= 14;
-	gnome_print_moveto (pc, 30, pos_y);
+	gnome_print_moveto (pc, 40, pos_y);
 	gnome_print_show (pc, buf);
 	g_free (buf);
 
 	/* Third line shows the effctive date of printing            */
-	/**** FIXME: string not translated (bug #522419) */
 	buf = g_strdup_printf (_("Effective: %s"), dnum2lstr (CurrentDaynum ()));
 	pos_y -= 14;
-	gnome_print_moveto (pc, 30, pos_y);
+	gnome_print_moveto (pc, 40, pos_y);
 	gnome_print_show (pc, buf);
 	g_free (buf);
 
 	/* Draw a break line                                         */
 	pos_y -= 10;
 	gnome_print_moveto (pc, 40, pos_y);
-	gnome_print_lineto (pc, paper_width - 40, pos_y);
+	gnome_print_lineto (pc, paper_width - 95, pos_y);
 	gnome_print_stroke (pc);
 	gnome_print_grestore (pc);
 
 }
 
 
-static void satp_sat_data_print (GnomePrintContext *pc, sat_t *sat)
+static void
+satp_sat_data_print (GnomePrintContext *pc, sat_t *sat)
 {
 	/* Print a single SAT's AOS/LOS data header                      */
 	/* Print the satellites name and the AOS/LOS header              */
@@ -241,7 +242,6 @@ static void satp_sat_data_print (GnomePrintContext *pc, sat_t *sat)
 	gnome_print_setfont (pc, font);
 
 	pos_y -= 20;
-	/**** FIXME: string not translated (bug #522419) */
 	textbuf = g_strdup_printf (_("Upcomming Passes for %s (%d)"), sat->name, sat->catnum);
 	gnome_print_moveto (pc, 150, pos_y);
 	gnome_print_show (pc, textbuf);
@@ -249,9 +249,9 @@ static void satp_sat_data_print (GnomePrintContext *pc, sat_t *sat)
 
 	pos_y -= 18;
 	gnome_print_moveto (pc, 120, pos_y);
-	gnome_print_show (pc, _("AOS (UTC)"));
+	gnome_print_show (pc, _("AOS"));
 	gnome_print_moveto (pc, 320, pos_y);
-	gnome_print_show (pc, _("LOS (UTC)"));
+	gnome_print_show (pc, _("LOS"));
 
 	gnome_print_grestore (pc);
 
@@ -259,12 +259,12 @@ static void satp_sat_data_print (GnomePrintContext *pc, sat_t *sat)
 }
 
 
-static gint satp_aosline_print (GnomePrintContext *pc,gchar *linebuf)
+static gint
+satp_aosline_print (GnomePrintContext *pc,gchar *linebuf)
 {
 	/* Print the AOS/LOS data                                     */
 	/* The function recieves an entry from the global list        */
 	/* splits into two elemets and print                          */
-
 	gchar **vbuff;
 
 	vbuff = g_strsplit (linebuf,";",2);
@@ -273,26 +273,26 @@ static gint satp_aosline_print (GnomePrintContext *pc,gchar *linebuf)
 		satp_highlight_line (pc, 40, 500, 12);
 		gHighlight = 0;
 	} else { gHighlight = 1;}
- 
 
 	gnome_print_gsave (pc);
        
-      /* 1st data element - the AOS */
+	/* 1st data element - the AOS */
 	gnome_print_moveto (pc, 60, pos_y);
 	gnome_print_show (pc, vbuff[0]);
 
-      /* 2nd data element - the LOS */
+	/* 2nd data element - the LOS */
 	gnome_print_moveto (pc, 260, pos_y);
 	gnome_print_show (pc, vbuff[1]);
 
 	g_strfreev (vbuff);
 	gnome_print_grestore (pc); 
 
-	return 0;  /* Meaning? Bug #509688 */
+	return 0;
 }
 
 
-static gint satp_sat_textline (GnomePrintContext *pc, gchar **textbuf)
+static gint
+satp_sat_textline (GnomePrintContext *pc, gchar **textbuf)
 {
 
 	/* Print a single line of Satellite data                            */
@@ -326,11 +326,12 @@ static gint satp_sat_textline (GnomePrintContext *pc, gchar **textbuf)
 
 	gnome_print_grestore (pc);
 
-	return 0;  /* Meaning? Bug #509688 */
+	return 0;
 }
 
 
-static gint satp_satline_print (GnomePrintContext *pc, guint index )
+static gint
+satp_satline_print (GnomePrintContext *pc, guint index )
 {
 
 	/* Print all list from the SATLIST on display                       */
@@ -373,11 +374,13 @@ static gint satp_satline_print (GnomePrintContext *pc, guint index )
 	satp_sat_textline (pc, text);
 	g_strfreev (text);
 	g_free (aos_los);
+
 	return 0;
 }
 
 
-static void satp_satlist_header (GnomePrintContext *pc)
+static void
+satp_satlist_header (GnomePrintContext *pc)
 {
 	/* Header line for sat list                                          */
 	GnomeFont *font;
@@ -398,7 +401,8 @@ static void satp_satlist_header (GnomePrintContext *pc)
 }
 
 
-static void satp_satlist_print (GnomePrintContext *pc)
+static void
+satp_satlist_print (GnomePrintContext *pc)
 {
 	/* Print the list of prediction for all the displayed list           */
 	guint num_of_sats;
@@ -446,34 +450,41 @@ static void satp_satlist_print (GnomePrintContext *pc)
 }
 
 
-static void satp_aosdet_header (GnomePrintContext *pc)
+static void satp_aosdet_header (GnomePrintContext *pc, sat_t *sat, guint orbit)
 {
-	/* Header line for sat list                                          */
+	/* Header line for sat list */
 	GnomeFont *font;
+	gchar *textbuf;
 
 	font = gnome_font_new_closest ("Times", GNOME_FONT_BOLD, 1, 13);
 	gnome_print_gsave (pc);
 	gnome_print_setfont (pc, font);
 
-	pos_y -= 13;
-	gnome_print_moveto (pc, 60, pos_y);
-	gnome_print_show (pc, _("Time (UTC)"));
+	pos_y -= 15;
+	textbuf = g_strdup_printf (_("Upcoming Pass for %s (%d),  orbit %d"), sat->name, sat->catnum, orbit);
+	gnome_print_moveto (pc, 140, pos_y);
+	gnome_print_show (pc, textbuf);
+	g_free (textbuf);
+
+	pos_y -= 20;
+	gnome_print_moveto (pc, 80, pos_y);
+	gnome_print_show (pc, _("Time"));
   
-	gnome_print_moveto (pc, 190, pos_y);
+	gnome_print_moveto (pc, 210, pos_y);
 	gnome_print_show (pc, _("Az"));
 
-	gnome_print_moveto (pc, 250, pos_y);
+	gnome_print_moveto (pc, 270, pos_y);
 	gnome_print_show (pc, _("El"));
 
 
-	gnome_print_moveto (pc, 285, pos_y);
-	gnome_print_show (pc, _("Latitude"));
+	gnome_print_moveto (pc, 315, pos_y);
+	gnome_print_show (pc, _("Lat"));
 
-	gnome_print_moveto (pc, 360, pos_y);
-	gnome_print_show (pc, _("Longitude"));
+	gnome_print_moveto (pc, 390, pos_y);
+	gnome_print_show (pc, _("Lon"));
   
-	gnome_print_moveto (pc, 440, pos_y);
-	gnome_print_show (pc, _("Altitude"));
+	gnome_print_moveto (pc, 465, pos_y);
+	gnome_print_show (pc, _("Alt"));
 
 	gnome_print_grestore (pc);
 
@@ -482,50 +493,53 @@ static void satp_aosdet_header (GnomePrintContext *pc)
 }
 
 
-static gint satp_aosdetline_print (GnomePrintContext *pc, gchar *aosdetline)
+static gint
+satp_aosdetline_print (GnomePrintContext *pc, gchar *aosdetline)
 {
 	gchar **textbuf;
 
 	if (gHighlight == 1) {
-		satp_highlight_line (pc, 30, 550, 12);
+		satp_highlight_line (pc, 60, 500, 12);
 		gHighlight = 0;
 	} else { gHighlight = 1;}
 
 	textbuf = g_strsplit (aosdetline, ";", 9);
 	gnome_print_gsave (pc);
 
-	/* 1st data element - the time (UTC)                            */
-	gnome_print_moveto (pc, 30, pos_y);
+	/* 1st data element - the time                             */
+	gnome_print_moveto (pc, 40, pos_y);
 	gnome_print_show (pc, textbuf[0]);
 
 	/* 2nd data element - the Azimuth to the satellite              */
-	gnome_print_moveto (pc, 180, pos_y);
+	gnome_print_moveto (pc, 190, pos_y);
 	gnome_print_show (pc, textbuf[1]);
 
 	/* 3rd data element - the elevation                             */
-	gnome_print_moveto (pc, 230, pos_y);
+	gnome_print_moveto (pc, 240, pos_y);
 	gnome_print_show (pc, textbuf[2]);
 
 	/* 4th data element - the Latitude of the Satellite             */
-	gnome_print_moveto (pc, 280, pos_y);
+	gnome_print_moveto (pc, 290, pos_y);
 	gnome_print_show (pc, textbuf[3]);
 
 	/* 5th data element - the Longitude of the Satellite            */
-	gnome_print_moveto (pc, 360, pos_y);
+	gnome_print_moveto (pc, 370, pos_y);
 	gnome_print_show (pc, textbuf[4]);
   
 	/* The satellite height is the 6th element                      */
-	gnome_print_moveto (pc, 440, pos_y);
+	gnome_print_moveto (pc, 450, pos_y);
 	gnome_print_show (pc, textbuf[5]);
 
 	gnome_print_grestore (pc);
 	g_strfreev (textbuf);
+
 	return 0;
 }
 
 
 /* Callback function activated when user presses the print button */
-void sat_print_current(void)
+void
+sat_print_current (void)
 {
 	GnomePrinter *printer;
 	GnomePrintContext *pc;
@@ -548,7 +562,8 @@ void sat_print_current(void)
 
 
 /* Callback function when user prints the AOS/LOS prediction for a satellite */
-void sat_print_sat_aos (sat_t *sat, gchar **aoslist, guint size)
+void 
+sat_print_sat_aos (sat_t *sat, gchar **aoslist, guint size)
 {
 	/* Print the detailed AOS List                                   */
 	GnomePrinter *printer;
@@ -563,19 +578,15 @@ void sat_print_sat_aos (sat_t *sat, gchar **aoslist, guint size)
 		return;
 
 	satp_calc_paper_size (UsePaper);
-	pos_y = paper_height;         /* upper print margin               */ 
+	pos_y = paper_height - 20;         /* upper print margin */ 
 
 	pc = gnome_print_context_new_with_paper_size (printer, UsePaper);
-
 	gnome_print_beginpage (pc, _("Gnome-Predict Sat Prediction"));
-
 	satp_page_header (pc);
-
 	satp_print_qth (pc);
-
 	satp_sat_data_print (pc, sat);
 
-	/* Just initialize the Highlight controller                       */ 
+	/* Just initialize the Highlight controller */ 
 	gHighlight = 0;
 
 	gnome_print_gsave (pc);
@@ -595,8 +606,11 @@ void sat_print_sat_aos (sat_t *sat, gchar **aoslist, guint size)
 } 
 
 
-void sat_print_aos_det (sat_t *sat, gchar **aosdet, guint size)
+void
+sat_print_aos_det (sat_t *sat, gchar **aosdet, guint size, guint orbit)
 {
+	/* Detailed AOS prediction */
+
 	GnomePrinter *printer;
 	GnomePrintContext *pc;
 	GnomeFont *font;
@@ -610,9 +624,9 @@ void sat_print_aos_det (sat_t *sat, gchar **aosdet, guint size)
 		return;
 
 	satp_calc_paper_size (UsePaper);
+
 	font = gnome_font_new ("Courier", 12);
 	pc = gnome_print_context_new_with_paper_size (printer, UsePaper);
-	gnome_print_beginpage (pc, _("Gnome-Predict AOS Details"));
 
 	/* get number of datalines and calculate required pages */
 	pages = size / PG_DATA_LINES;
@@ -620,16 +634,17 @@ void sat_print_aos_det (sat_t *sat, gchar **aosdet, guint size)
 	sindex = 1;
 	eindex = (size > PG_DATA_LINES) ? PG_DATA_LINES : size -1;
 
-	/**** FIXME: string not translated (bug #522419) */
 	buf = g_strdup_printf (_("Size: %d, Pages %d, eindex %d"), size, pages, eindex);
-	satlog_log (SAT_LOG_CRITICAL, buf);
+	satlog_log (SAT_LOG_DEBUG, buf);
 	g_free (buf);
 
 	for (page = 1; page <= pages; page++) {
-		pos_y = paper_height;
+		pos_y = paper_height - 20;
+		/* this will add page numbers as well */
+		gnome_print_beginpage (pc, _("Gnome-Predict AOS Details"));
 		satp_page_header (pc);
 		satp_print_qth (pc);
-		satp_aosdet_header (pc);
+		satp_aosdet_header (pc, sat, orbit);
 		gnome_print_setfont (pc, font);
 		gHighlight = 0;
 		for (lindex = sindex; lindex <= eindex ; lindex++) {
